@@ -12,14 +12,18 @@ import datetime
 import os
 import re
 import sys
+import asyncio
+import platform
+import matplotlib
 
+matplotlib.use("Agg")
 # -- Path setup --------------------------------------------------------------
 
 # If extensions (or modules to document with autodoc) are in another directory,
 # add these directories to sys.path here. If the directory is relative to the
 # documentation root, use os.path.abspath to make it absolute, like shown here.
 #
-# sys.path.insert(0, os.path.abspath('.'))
+sys.path.insert(0, os.path.abspath("."))
 sys.path.insert(0, os.path.abspath("../"))
 
 
@@ -37,6 +41,7 @@ project = "NeuroKit2"
 copyright = f"2020–{datetime.datetime.now().year}"
 author = '<a href="https://dominiquemakowski.github.io/">Dominique Makowski</a> and the <a href="https://github.com/neuropsychology/NeuroKit/blob/master/AUTHORS.rst">Team</a>. This documentation is licensed under a <a href="https://creativecommons.org/licenses/by/4.0/">CC BY 4.0</a> license.'
 
+
 # The short X.Y version.
 def find_version():
     result = re.search(
@@ -67,6 +72,7 @@ extensions = [
     "sphinxemoji.sphinxemoji",
     "sphinx_copybutton",
     "myst_nb",
+    "directives.csv_codebook_directive",
 ]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -91,7 +97,9 @@ napoleon_numpy_docstring = True
 napoleon_use_param = False
 napoleon_use_ivar = False
 napoleon_use_rtype = False
-add_module_names = False  # If true, the current module name will be prepended to all description
+add_module_names = (
+    False  # If true, the current module name will be prepended to all description
+)
 
 # -- Options for ipython directive  ----------------------------------------
 
@@ -105,6 +113,9 @@ nb_execution_raise_on_error = True
 
 # googleanalytics_id = "G-DVXSEGN5M9"
 
+# Address asyncio warning
+if platform.system() == "Windows":
+    asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())
 
 # NumPyDoc configuration -----------------------------------------------------
 
@@ -126,8 +137,9 @@ html_theme_options = {
     "use_issues_button": True,
     "path_to_docs": "docs/",
     "use_edit_page_button": True,
-    "logo_only": True,
+    # "logo_only": True,
     "show_toc_level": 1,
+    "navigation_with_keys": False,
 }
 
 
