@@ -7,13 +7,15 @@ from .optim_complexity_k import _complexity_k_slope, complexity_k
 
 
 def fractal_higuchi(signal, k_max="default", show=False, **kwargs):
-    """Computes Higuchi's Fractal Dimension (HFD) by reconstructing k-max number of new
-    data sets. For each reconstructed data set, curve length is computed and plotted
-    against its corresponding k value on a log-log scale. HFD equates to the slope obtained
-    from fitting a least-squares method.
+    """**Higuchi's Fractal Dimension (HFD)**
 
-    Values should fall between 1 and 2. For more information about k parameter selection, see
-    the ``complexity_k()`` optimization function.
+    The Higuchi's Fractal Dimension (HFD) is an approximate value for the box-counting dimension for
+    time series. It is computed by reconstructing k-max number of new data sets. For each
+    reconstructed data set, curve length is computed and plotted against its corresponding
+    *k*-value on a log-log scale. HFD corresponds to the slope of the least-squares linear trend.
+
+    Values should fall between 1 and 2. For more information about the *k* parameter selection, see
+    the :func:`complexity_k` optimization function.
 
     Parameters
     ----------
@@ -21,8 +23,7 @@ def fractal_higuchi(signal, k_max="default", show=False, **kwargs):
         The signal (i.e., a time series) in the form of a vector of values.
     k_max : str or int
         Maximum number of interval times (should be greater than or equal to 2).
-        If "default", then the optimal kmax is computed based on the point at which HFD values plateau
-        for a range of kmax values (see ``complexity_k()`` optimization function).
+        If ``"default"``, the optimal k-max is estimated using :func:`complexity_k`, which is slow.
     show : bool
         Visualise the slope of the curve for the selected k_max value.
     **kwargs : optional
@@ -30,28 +31,46 @@ def fractal_higuchi(signal, k_max="default", show=False, **kwargs):
 
     Returns
     ----------
-    slope : float
-        Higuchi's fractal dimension of the single time series.
+    HFD : float
+        Higuchi's fractal dimension of the time series.
     info : dict
         A dictionary containing additional information regarding the parameters used
         to compute Higuchi's fractal dimension.
 
+    See Also
+    --------
+    complexity_k
+
     Examples
     ----------
-    >>> import neurokit2 as nk
-    >>>
-    >>> signal = nk.signal_simulate(duration=1, sampling_rate=100, frequency=[3, 6], noise = 0.2)
-    >>>
-    >>> hfd, info = nk.fractal_higuchi(signal, k_max='default', show=True)
-    >>> hfd #doctest: +SKIP
+    .. ipython:: python
 
-    Reference
+      import neurokit2 as nk
+
+      signal = nk.signal_simulate(duration=1, sampling_rate=100, frequency=[3, 6], noise = 0.2)
+
+      @savefig p_fractal_higuchi1.png scale=100%
+      k_max, info =  nk.complexity_k(signal, k_max='default', show=True)
+      @suppress
+      plt.close()
+
+      @savefig p_fractal_higuchi2.png scale=100%
+      hfd, info = nk.fractal_higuchi(signal, k_max=k_max, show=True)
+      @suppress
+      plt.close()
+
+    .. ipython:: python
+
+      hfd
+
+    References
     ----------
-    - Higuchi, T. (1988). Approach to an irregular time series on the basis of the fractal theory.
-    Physica D: Nonlinear Phenomena, 31(2), 277-283.
+    * Higuchi, T. (1988). Approach to an irregular time series on the basis of the fractal theory.
+      Physica D: Nonlinear Phenomena, 31(2), 277-283.
+    * Vega, C. F., & Noel, J. (2015, June). Parameters analyzed of Higuchi's fractal dimension for
+      EEG brain signals. In 2015 Signal Processing Symposium (SPSympo) (pp. 1-5). IEEE.
+      https://ieeexplore.ieee.org/document/7168285
 
-    - Vega, C. F., & Noel, J. (2015, June). Parameters analyzed of Higuchi's fractal dimension for EEG brain signals.
-    In 2015 Signal Processing Symposium (SPSympo) (pp. 1-5). IEEE. https://ieeexplore.ieee.org/document/7168285
     """
 
     # Sanity checks
@@ -62,7 +81,7 @@ def fractal_higuchi(signal, k_max="default", show=False, **kwargs):
 
     # Get k_max
     if isinstance(k_max, (str, list, np.ndarray, pd.Series)):
-        # optimizing needed
+        # Optimizing needed
         k_max, info = complexity_k(signal, k_max=k_max, show=False)
         idx = np.where(info["Values"] == k_max)[0][0]
         slope = info["Scores"][idx]
@@ -70,7 +89,7 @@ def fractal_higuchi(signal, k_max="default", show=False, **kwargs):
         average_values = info["Average_Values"][idx]
         k_values = np.arange(1, k_max + 1)
     else:
-        # Compute higushi
+        # Compute Higuchi
         slope, intercept, info = _complexity_k_slope(k_max, signal)
         k_values = info["k_values"]
         average_values = info["average_values"]
