@@ -6,11 +6,14 @@ import pandas as pd
 import scipy.cluster.vq
 import scipy.special
 
+from ..misc import check_random_state
 from ..stats import standardize
 from .optim_complexity_tolerance import complexity_tolerance
 
 
-def complexity_symbolize(signal, method="mean", c=3, show=False, **kwargs):
+def complexity_symbolize(
+    signal, method="mean", c=3, random_state=None, show=False, **kwargs
+):
     """**Signal Symbolization and Discretization**
 
     Many complexity indices are made to assess the recurrence and predictability of discrete -
@@ -21,7 +24,7 @@ def complexity_symbolize(signal, method="mean", c=3, show=False, **kwargs):
     developped to that end.
 
     * **Method 'A'** binarizes the signal by higher vs. lower values as compated to the signal's
-      mean. Equivalent tp ``method="mean"`` (``method="median"`` is also valid).
+      mean. Equivalent to ``method="mean"`` (``method="median"`` is also valid).
     * **Method 'B'** uses values that are within the mean +/- 1 SD band vs. values that are outside
       this band.
     * **Method 'C'** computes the difference between consecutive samples and binarizes depending on
@@ -54,6 +57,8 @@ def complexity_symbolize(signal, method="mean", c=3, show=False, **kwargs):
         See :func:`complexity_symbolize` for details.
     c : int
         Number of symbols *c*, used in some algorithms.
+    random_state : None, int, numpy.random.RandomState or numpy.random.Generator
+        Seed for the random number generator. See :func:`misc.check_random_state` for further information.
     show : bool
         Plot the reconstructed attractor. See :func:`complexity_attractor` for details.
     **kwargs
@@ -152,16 +157,21 @@ def complexity_symbolize(signal, method="mean", c=3, show=False, **kwargs):
     .. ipython:: python
 
       @savefig p_complexity_symbolize11.png scale=100%
-      symbolic = nk.complexity_symbolize(signal, method = "kmeans", c=5, show=True)
+      symbolic = nk.complexity_symbolize(signal, method = "kmeans", c=5, random_state=42, show=True)
       @suppress
       plt.close()
 
     """
+    # Seed the random generator for reproducible results
+    rng = check_random_state(random_state)
+
     # Do nothing
     if method is None:
         symbolic = signal
         if show is True:
-            df = pd.DataFrame({"Signal": signal, "Bin": signal, "Index": np.arange(len(signal))})
+            df = pd.DataFrame(
+                {"Signal": signal, "Bin": signal, "Index": np.arange(len(signal))}
+            )
             df = df.pivot_table(index="Index", columns="Bin", values="Signal")
             for i in df.columns:
                 plt.plot(df[i])
@@ -178,8 +188,8 @@ def complexity_symbolize(signal, method="mean", c=3, show=False, **kwargs):
             symbolic = (signal > np.nanmean(signal)).astype(int)
             if show is True:
                 df = pd.DataFrame({"A": signal, "B": signal})
-                df["A"][df["A"] > np.nanmean(signal)] = np.nan
-                df["B"][df["B"] <= np.nanmean(signal)] = np.nan
+                df.loc[df["A"] > np.nanmean(signal), "A"] = np.nan
+                df.loc[df["B"] <= np.nanmean(signal), "B"] = np.nan
                 df.plot()
                 plt.axhline(y=np.nanmean(signal), color="r", linestyle="dotted")
                 plt.title("Method A")
@@ -188,8 +198,8 @@ def complexity_symbolize(signal, method="mean", c=3, show=False, **kwargs):
             symbolic = (signal > np.nanmedian(signal)).astype(int)
             if show is True:
                 df = pd.DataFrame({"A": signal, "B": signal})
-                df["A"][df["A"] > np.nanmedian(signal)] = np.nan
-                df["B"][df["B"] <= np.nanmedian(signal)] = np.nan
+                df.loc[df["A"] > np.nanmedian(signal), "A"] = np.nan
+                df.loc[df["B"] <= np.nanmedian(signal), "B"] = np.nan
                 df.plot()
                 plt.axhline(y=np.nanmean(signal), color="r", linestyle="dotted")
                 plt.title("Binarization by median")
@@ -200,8 +210,9 @@ def complexity_symbolize(signal, method="mean", c=3, show=False, **kwargs):
             symbolic = np.logical_or(signal < m - sd, signal > m + sd).astype(int)
             if show is True:
                 df = pd.DataFrame({"A": signal, "B": signal})
-                df["A"][np.logical_or(signal < m - sd, signal > m + sd)] = np.nan
-                df["B"][~np.isnan(df["A"])] = np.nan
+                condition = np.logical_or(signal < m - sd, signal > m + sd)
+                df.loc[condition, "A"] = np.nan
+                df.loc[~np.isnan(df["A"]), "B"] = np.nan
                 df.plot()
                 plt.axhline(y=m - sd, color="r", linestyle="dotted")
                 plt.axhline(y=m + sd, color="r", linestyle="dotted")
@@ -211,8 +222,8 @@ def complexity_symbolize(signal, method="mean", c=3, show=False, **kwargs):
             symbolic = np.signbit(np.diff(signal)).astype(int)
             if show is True:
                 df = pd.DataFrame({"A": signal, "B": signal})
-                df["A"][np.insert(symbolic, 0, False)] = np.nan
-                df["B"][~np.isnan(df["A"])] = np.nan
+                df.loc[np.insert(symbolic, 0, False), "A"] = np.nan
+                df.loc[~np.isnan(df["A"]), "B"] = np.nan
                 df.plot()
                 plt.title("Method C")
 
@@ -221,25 +232,41 @@ def complexity_symbolize(signal, method="mean", c=3, show=False, **kwargs):
             if show is True:
                 where = np.where(symbolic)[0]
                 plt.plot(signal, zorder=1 == 1)
-                plt.scatter(where, signal[where], color="orange", label="Inversion", zorder=2)
+                plt.scatter(
+                    where, signal[where], color="orange", label="Inversion", zorder=2
+                )
                 plt.title("Method D")
 
         elif method == "r":
-            symbolic = np.abs(np.diff(signal)) > complexity_tolerance(signal, method="sd")[0]
+            symbolic = (
+                np.abs(np.diff(signal)) > complexity_tolerance(signal, method="sd")[0]
+            )
             symbolic = symbolic.astype(int)
             if show is True:
                 where = np.where(symbolic == 1)[0]
                 plt.plot(signal, zorder=1)
-                plt.scatter(where, signal[where], color="orange", label="Inversion", zorder=2)
+                plt.scatter(
+                    where, signal[where], color="orange", label="Inversion", zorder=2
+                )
                 plt.title("Method based on tolerance r")
 
-        elif method in ["binning", "mep", "ncdf", "linear", "uniform", "kmeans", "equal"]:
+        elif method in [
+            "binning",
+            "mep",
+            "ncdf",
+            "linear",
+            "uniform",
+            "kmeans",
+            "equal",
+        ]:
             n = len(signal)
             if method == "binning":
                 symbolic = pd.cut(signal, bins=c, labels=False)
 
             elif method == "mep":
-                Temp = np.hstack((0, np.ceil(np.arange(1, c) * len(signal) / c) - 1)).astype(int)
+                Temp = np.hstack(
+                    (0, np.ceil(np.arange(1, c) * len(signal) / c) - 1)
+                ).astype(int)
                 symbolic = np.digitize(signal, np.sort(signal)[Temp])
             elif method == "ncdf":
                 symbolic = np.digitize(
@@ -247,13 +274,16 @@ def complexity_symbolize(signal, method="mean", c=3, show=False, **kwargs):
                 )
             elif method == "linear":
                 symbolic = np.digitize(
-                    signal, np.arange(np.min(signal), np.max(signal), np.ptp(signal) / c)
+                    signal,
+                    np.arange(np.min(signal), np.max(signal), np.ptp(signal) / c),
                 )
             elif method == "uniform":
                 symbolic = np.zeros(len(signal))
-                symbolic[np.argsort(signal)] = np.digitize(np.arange(n), np.arange(0, 2 * n, n / c))
+                symbolic[np.argsort(signal)] = np.digitize(
+                    np.arange(n), np.arange(0, 2 * n, n / c)
+                )
             elif method == "kmeans":
-                centroids, labels = scipy.cluster.vq.kmeans2(signal, c)
+                centroids, labels = scipy.cluster.vq.kmeans2(signal, c, seed=rng)
                 labels += 1
                 xx = np.argsort(centroids) + 1
                 symbolic = np.zeros(n)
