@@ -3,6 +3,7 @@ import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
 import scipy.signal
+import pywt
 
 from ..epochs import epochs_create, epochs_to_df
 from ..signal import (
@@ -49,8 +50,13 @@ def ecg_delineate(
     sampling_rate : int
         The sampling frequency of ``ecg_signal`` (in Hz, i.e., samples/second). Defaults to 1000.
     method : str
-        Can be one of ``"peak"`` for a peak-based method, ``"cwt"`` for continuous wavelet transform
-        or ``"dwt"`` (default) for discrete wavelet transform.
+        Can be one of ``"peak"`` for a peak-based method, ``"prominence"`` for a peak-prominence-based
+        method (Emrich et al., 2024), ``"cwt"`` for continuous wavelet transform or ``"dwt"`` (default)
+        for discrete wavelet transform.
+        The ``"prominence"`` method might be useful to detect the waves, allowing to set individual physiological
+        limits (see kwargs), while the ``"dwt"`` method might be more precise for detecting the onsets and offsets
+        of the waves (but might exhibit lower accuracy when there is significant variation in wave morphology).
+        The ``"peak"`` method, which uses the zero-crossings of the signal derivatives, works best with very clean signals.
     show : bool
         If ``True``, will return a plot to visualizing the delineated waves information.
     show_type: str
@@ -60,7 +66,16 @@ def ecg_delineate(
         Defaults to ``False``. If ``True``, replaces the delineated features with ``np.nan`` if its
         standardized distance from R-peaks is more than 3.
     **kwargs
-        Other optional arguments.
+        Other optional arguments:
+        If using the ``"prominence"`` method, additional parameters (in milliseconds) can be passed to set
+        individual physiological limits for the search boundaries:
+        - ``max_qrs_interval``: The maximum allowable QRS complex interval. Defaults to 180 ms.
+        - ``max_pr_interval``: The maximum PR interval duration. Defaults to 300 ms.
+        - ``max_r_rise_time``: Maximum duration for the R-wave rise. Defaults to 120 ms.
+        - ``typical_st_segment``: Typical duration of the ST segment. Defaults to 150 ms.
+        - ``max_p_basepoint_interval``: The maximum interval between P-wave on- and offset. Defaults to 100 ms.
+        - ``max_r_basepoint_interval``: The maximum interval between R-wave on- and offset. Defaults to 100 ms.
+        - ``max_t_basepoint_interval``: The maximum interval between T-wave on- and offset. Defaults to 200 ms.
 
     Returns
     -------
@@ -71,7 +86,7 @@ def ecg_delineate(
         ``"ECG_Q_Peaks"``, ``"ECG_S_Peaks"``, ``"ECG_T_Peaks"``, ``"ECG_P_Onsets"``,
         ``"ECG_T_Offsets"``, respectively.
 
-        For wavelet methods, in addition to the above information, the dictionary contains the
+        For the wavelet and prominence methods, in addition to the above information, the dictionary contains the
         samples at which QRS-onsets and QRS-offsets occur, accessible with the key
         ``"ECG_P_Peaks"``, ``"ECG_T_Peaks"``, ``"ECG_P_Onsets"``, ``"ECG_P_Offsets"``,
         ``"ECG_Q_Peaks"``, ``"ECG_S_Peaks"``, ``"ECG_T_Onsets"``, ``"ECG_T_Offsets"``,
@@ -114,6 +129,8 @@ def ecg_delineate(
     - Martínez, J. P., Almeida, R., Olmos, S., Rocha, A. P., & Laguna, P. (2004). A wavelet-based
       ECG delineator: evaluation on standard databases. IEEE Transactions on biomedical engineering,
       51(4), 570-581.
+    - Emrich, J., Gargano, A., Koka, T., & Muma, M. (2024). Physiology-Informed ECG Delineation Based
+      on Peak Prominence. 32nd European Signal Processing Conference (EUSIPCO), 1402-1406.
 
     """
     # Sanitize input for ecg_cleaned
@@ -153,21 +170,35 @@ def ecg_delineate(
 
     method = method.lower()  # remove capitalised letters
     if method in ["peak", "peaks", "derivative", "gradient"]:
-        waves = _ecg_delineator_peak(ecg_cleaned, rpeaks=rpeaks, sampling_rate=sampling_rate)
+        waves = _ecg_delineator_peak(
+            ecg_cleaned, rpeaks=rpeaks, sampling_rate=sampling_rate
+        )
     elif method in ["cwt", "continuous wavelet transform"]:
-        waves = _ecg_delineator_cwt(ecg_cleaned, rpeaks=rpeaks, sampling_rate=sampling_rate)
+        waves = _ecg_delineator_cwt(
+            ecg_cleaned, rpeaks=rpeaks, sampling_rate=sampling_rate
+        )
     elif method in ["dwt", "discrete wavelet transform"]:
         waves = _dwt_ecg_delineator(ecg_cleaned, rpeaks, sampling_rate=sampling_rate)
+    elif method in ["prominence", "peak-prominence", "emrich", "emrich2024"]:
+        waves = _prominence_ecg_delineator(ecg_cleaned, rpeaks=rpeaks, sampling_rate=sampling_rate, **kwargs)
 
     else:
         raise ValueError(
-            "NeuroKit error: ecg_delineate(): 'method' should be one of 'peak'," "'cwt' or 'dwt'."
+            "NeuroKit error: ecg_delineate(): 'method' should be one of 'peak', 'prominence',"
+            "'cwt' or 'dwt'."
         )
 
+    # Ensure that all indices are not larger than ECG signal indices
+    for _, value in waves.items():
+        if value[-1] >= len(ecg_cleaned):
+            value[-1] = np.nan
+
     # Remove NaN in Peaks, Onsets, and Offsets
     waves_noNA = waves.copy()
     for feature in waves_noNA.keys():
-        waves_noNA[feature] = [int(x) for x in waves_noNA[feature] if ~np.isnan(x) and x > 0]
+        waves_noNA[feature] = [
+            int(x) for x in waves_noNA[feature] if ~np.isnan(x) and x > 0
+        ]
 
     instant_peaks = signal_formatpeaks(waves_noNA, desired_length=len(ecg_cleaned))
     signals = instant_peaks
@@ -197,14 +228,18 @@ def ecg_delineate(
 # =============================================================================
 def _dwt_resample_points(peaks, sampling_rate, desired_sampling_rate):
     """Resample given points to a different sampling rate."""
-    if isinstance(peaks, np.ndarray):  # peaks are passed in from previous processing steps
+    if isinstance(
+        peaks, np.ndarray
+    ):  # peaks are passed in from previous processing steps
         # Prevent overflow by converting to np.int64 (peaks might be passed in containing np.int32).
         peaks = peaks.astype(dtype=np.int64)
     elif isinstance(peaks, list):  # peaks returned from internal functions
         # Cannot be converted to int since list might contain np.nan. Automatically cast to np.float64 if list contains np.nan.
         peaks = np.array(peaks)
     peaks_resample = peaks * desired_sampling_rate / sampling_rate
-    peaks_resample = [np.nan if np.isnan(x) else int(x) for x in peaks_resample.tolist()]
+    peaks_resample = [
+        np.nan if np.isnan(x) else int(x) for x in peaks_resample.tolist()
+    ]
     return peaks_resample
 
 
@@ -237,7 +272,9 @@ def _dwt_ecg_delineator(ecg, rpeaks, sampling_rate, analysis_sampling_rate=2000)
     for i, rpeak in enumerate(rpeaks):
         heartbeat = heartbeats[str(i + 1)]
         # Get index of R peaks
-        R = heartbeat.index.get_loc(np.min(heartbeat.index.values[heartbeat.index.values > 0]))
+        R = heartbeat.index.get_loc(
+            np.min(heartbeat.index.values[heartbeat.index.values > 0])
+        )
         # Q wave
         Q_index, Q = _ecg_delineator_peak_Q(rpeak, heartbeat, R)
         qpeaks.append(Q_index)
@@ -258,13 +295,23 @@ def _dwt_ecg_delineator(ecg, rpeaks, sampling_rate, analysis_sampling_rate=2000)
     # plt.legend()
     # plt.grid(True)
     # plt.show()
-    rpeaks_resampled = _dwt_resample_points(rpeaks, sampling_rate, analysis_sampling_rate)
+    rpeaks_resampled = _dwt_resample_points(
+        rpeaks, sampling_rate, analysis_sampling_rate
+    )
+    qpeaks_resampled = _dwt_resample_points(
+        qpeaks, sampling_rate, analysis_sampling_rate
+    )
 
     tpeaks, ppeaks = _dwt_delineate_tp_peaks(
         ecg, rpeaks_resampled, dwtmatr, sampling_rate=analysis_sampling_rate
     )
     qrs_onsets, qrs_offsets = _dwt_delineate_qrs_bounds(
-        rpeaks_resampled, dwtmatr, ppeaks, tpeaks, sampling_rate=analysis_sampling_rate
+        rpeaks_resampled,
+        dwtmatr,
+        ppeaks,
+        tpeaks,
+        qpeaks_resampled,
+        sampling_rate=analysis_sampling_rate,
     )
     ponsets, poffsets = _dwt_delineate_tp_onsets_offsets(
         ppeaks, rpeaks_resampled, dwtmatr, sampling_rate=analysis_sampling_rate
@@ -378,12 +425,11 @@ def _dwt_delineate_tp_peaks(
         srch_idx_start = rpeak_ + srch_bndry
         srch_idx_end = rpeak_ + 2 * int(rt_duration * sampling_rate)
         dwt_local = dwtmatr[degree_tpeak + degree_add, srch_idx_start:srch_idx_end]
-        height = epsilon_T_weight * np.sqrt(np.mean(np.square(dwt_local)))
-
         if len(dwt_local) == 0:
             tpeaks.append(np.nan)
             continue
 
+        height = epsilon_T_weight * np.sqrt(np.mean(np.square(dwt_local)))
         ecg_local = ecg[srch_idx_start:srch_idx_end]
         peaks, __ = scipy.signal.find_peaks(np.abs(dwt_local), height=height)
         peaks = list(
@@ -401,7 +447,8 @@ def _dwt_delineate_tp_peaks(
             )  # pylint: disable=R1716
             if correct_sign:
                 idx_zero = (
-                    signal_zerocrossings(dwt_local[idx_peak : idx_peak_nxt + 1])[0] + idx_peak
+                    signal_zerocrossings(dwt_local[idx_peak : idx_peak_nxt + 1])[0]
+                    + idx_peak
                 )
                 # This is the score assigned to each peak. The peak with the highest score will be
                 # selected.
@@ -415,7 +462,9 @@ def _dwt_delineate_tp_peaks(
             tpeaks.append(np.nan)
             continue
 
-        tpeaks.append(candidate_peaks[np.argmax(candidate_peaks_scores)] + srch_idx_start)
+        tpeaks.append(
+            candidate_peaks[np.argmax(candidate_peaks_scores)] + srch_idx_start
+        )
 
     ppeaks = []
     for rpeak in rpeaks:
@@ -427,15 +476,16 @@ def _dwt_delineate_tp_peaks(
         srch_idx_start = rpeak - 2 * int(p2r_duration * sampling_rate)
         srch_idx_end = rpeak - srch_bndry
         dwt_local = dwtmatr[degree_ppeak + degree_add, srch_idx_start:srch_idx_end]
-        height = epsilon_P_weight * np.sqrt(np.mean(np.square(dwt_local)))
-
         if len(dwt_local) == 0:
             ppeaks.append(np.nan)
             continue
 
+        height = epsilon_P_weight * np.sqrt(np.mean(np.square(dwt_local)))
         ecg_local = ecg[srch_idx_start:srch_idx_end]
         peaks, __ = scipy.signal.find_peaks(np.abs(dwt_local), height=height)
-        peaks = list(filter(lambda p: np.abs(dwt_local[p]) > 0.025 * max(dwt_local), peaks))
+        peaks = list(
+            filter(lambda p: np.abs(dwt_local[p]) > 0.025 * max(dwt_local), peaks)
+        )
         if dwt_local[0] > 0:  # just append
             peaks = [0] + peaks
 
@@ -448,7 +498,8 @@ def _dwt_delineate_tp_peaks(
             )  # pylint: disable=R1716
             if correct_sign:
                 idx_zero = (
-                    signal_zerocrossings(dwt_local[idx_peak : idx_peak_nxt + 1])[0] + idx_peak
+                    signal_zerocrossings(dwt_local[idx_peak : idx_peak_nxt + 1])[0]
+                    + idx_peak
                 )
                 # This is the score assigned to each peak. The peak with the highest score will be
                 # selected.
@@ -462,7 +513,9 @@ def _dwt_delineate_tp_peaks(
             ppeaks.append(np.nan)
             continue
 
-        ppeaks.append(candidate_peaks[np.argmax(candidate_peaks_scores)] + srch_idx_start)
+        ppeaks.append(
+            candidate_peaks[np.argmax(candidate_peaks_scores)] + srch_idx_start
+        )
 
     return tpeaks, ppeaks
 
@@ -505,7 +558,9 @@ def _dwt_delineate_tp_onsets_offsets(
         if not (dwt_local[: onset_slope_peaks[-1]] < epsilon_onset).any():
             onsets.append(np.nan)
             continue
-        candidate_onsets = np.where(dwt_local[: onset_slope_peaks[-1]] < epsilon_onset)[0]
+        candidate_onsets = np.where(dwt_local[: onset_slope_peaks[-1]] < epsilon_onset)[
+            0
+        ]
         onsets.append(candidate_onsets[-1] + srch_idx_start)
 
         # # only for debugging
@@ -543,13 +598,15 @@ def _dwt_delineate_tp_onsets_offsets(
     return onsets, offsets
 
 
-def _dwt_delineate_qrs_bounds(rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rate=250):
+def _dwt_delineate_qrs_bounds(
+    rpeaks, dwtmatr, ppeaks, tpeaks, qpeaks, sampling_rate=250
+):
     degree = _dwt_adjust_parameters(rpeaks, sampling_rate, target="degree")
     onsets = []
-    for i in range(len(rpeaks)):  # pylint: disable=C0200
+    for i in range(len(qpeaks)):  # pylint: disable=C0200
         # look for onsets
         srch_idx_start = ppeaks[i]
-        srch_idx_end = rpeaks[i]
+        srch_idx_end = qpeaks[i]
         if srch_idx_start is np.nan or srch_idx_end is np.nan:
             onsets.append(np.nan)
             continue
@@ -562,7 +619,9 @@ def _dwt_delineate_qrs_bounds(rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rate=250
         if not (-dwt_local[: onset_slope_peaks[-1]] < epsilon_onset).any():
             onsets.append(np.nan)
             continue
-        candidate_onsets = np.where(-dwt_local[: onset_slope_peaks[-1]] < epsilon_onset)[0]
+        candidate_onsets = np.where(
+            -dwt_local[: onset_slope_peaks[-1]] < epsilon_onset
+        )[0]
         onsets.append(candidate_onsets[-1] + srch_idx_start)
 
         # only for debugging
@@ -590,7 +649,8 @@ def _dwt_delineate_qrs_bounds(rpeaks, dwtmatr, ppeaks, tpeaks, sampling_rate=250
             offsets.append(np.nan)
             continue
         candidate_offsets = (
-            np.where(dwt_local[onset_slope_peaks[0] :] < epsilon_offset)[0] + onset_slope_peaks[0]
+            np.where(dwt_local[onset_slope_peaks[0] :] < epsilon_offset)[0]
+            + onset_slope_peaks[0]
         )
         offsets.append(candidate_offsets[0] + srch_idx_start)
 
@@ -637,7 +697,9 @@ def _dwt_compute_multiscales(ecg: np.ndarray, max_degree):
         T_deg = _apply_H_filter(intermediate_ret, power=deg)
         dwtmatr.append(S_deg)
         intermediate_ret = np.array(T_deg)
-    dwtmatr = [arr[: len(ecg)] for arr in dwtmatr]  # rescale transforms to the same length
+    dwtmatr = [
+        arr[: len(ecg)] for arr in dwtmatr
+    ]  # rescale transforms to the same length
     return np.array(dwtmatr)
 
 
@@ -645,7 +707,6 @@ def _dwt_compute_multiscales(ecg: np.ndarray, max_degree):
 # WAVELET METHOD (CWT)
 # =============================================================================
 def _ecg_delineator_cwt(ecg, rpeaks=None, sampling_rate=1000):
-
     # P-Peaks and T-Peaks
     tpeaks, ppeaks = _peaks_delineator(ecg, rpeaks, sampling_rate=sampling_rate)
 
@@ -672,7 +733,9 @@ def _ecg_delineator_cwt(ecg, rpeaks=None, sampling_rate=1000):
     for i, rpeak in enumerate(rpeaks):
         heartbeat = heartbeats[str(i + 1)]
         # Get index of R peaks
-        R = heartbeat.index.get_loc(np.min(heartbeat.index.values[heartbeat.index.values > 0]))
+        R = heartbeat.index.get_loc(
+            np.min(heartbeat.index.values[heartbeat.index.values > 0])
+        )
         # Q wave
         Q_index, Q = _ecg_delineator_peak_Q(rpeak, heartbeat, R)
         q_peaks.append(Q_index)
@@ -695,20 +758,201 @@ def _ecg_delineator_cwt(ecg, rpeaks=None, sampling_rate=1000):
     }
 
 
+# =============================================================================
+# PROMINENCE METHOD (Emrich et al., 2024)
+# =============================================================================
+def _prominence_ecg_delineator(ecg, rpeaks=None, sampling_rate=1000, **kwargs):
+    # pysiology-informed boundaries in milliseconds, adapt if needed
+    max_qrs_interval = int(kwargs.get("max_qrs_interval", 180) * sampling_rate / 1000)
+    max_pr_interval = int(kwargs.get("max_pr_interval", 300) * sampling_rate / 1000)
+    max_r_rise_time = int(kwargs.get("max_r_rise_time", 120) * sampling_rate / 1000)
+    typical_st_segment = int(kwargs.get("typical_st_segment", 150) * sampling_rate / 1000)
+    # max basepoint intervals
+    max_p_basepoint_interval = int(kwargs.get("max_p_basepoint_interval", 100) * sampling_rate / 1000)
+    max_r_basepoint_interval = int(kwargs.get("max_r_basepoint_interval", 100) * sampling_rate / 1000)
+    max_t_basepoint_interval = int(kwargs.get("max_t_basepoint_interval", 200) * sampling_rate / 1000)
+
+    waves = {
+        "ECG_P_Onsets": [],
+        "ECG_P_Peaks": [],
+        "ECG_P_Offsets": [],
+        "ECG_Q_Peaks": [],
+        "ECG_R_Onsets": [],
+        "ECG_R_Offsets": [],
+        "ECG_S_Peaks": [],
+        "ECG_T_Onsets": [],
+        "ECG_T_Peaks": [],
+        "ECG_T_Offsets": [],
+    }
+
+    # calculate RR intervals
+    rr = np.diff(rpeaks)
+    rr = np.insert(rr, 0, min(rr[0], 2 * rpeaks[0]))
+    rr = np.insert(rr, -1, min(rr[-1], 2 * rpeaks[-1]))
+
+    # iterate over all beats
+    left = 0
+    for i in range(len(rpeaks)):
+        # 1. split signal into segments
+        rpeak_pos = min(rpeaks[i], rr[i] // 2)
+        left = rpeaks[i] - rpeak_pos
+        right = rpeaks[i] + rr[i + 1] // 2
+        ecg_seg = ecg[left:right]
+
+        current_wave = {
+            "ECG_R_Peaks": rpeak_pos,
+        }
+
+        # 2. find local extrema in signal
+        local_maxima = scipy.signal.find_peaks(ecg_seg)[0]
+        local_minima = scipy.signal.find_peaks(-ecg_seg)[0]
+        local_extrema = np.concatenate((local_maxima, local_minima))
+
+        # 3. compute prominence weight
+        weight_maxima = _calc_prominence(local_maxima, ecg_seg, current_wave["ECG_R_Peaks"])
+        weight_minima = _calc_prominence(local_minima, ecg_seg, current_wave["ECG_R_Peaks"], minima=True)
+
+        if local_extrema.any():
+            # find waves
+            _prominence_find_q_wave(weight_minima, current_wave, max_r_rise_time)
+            _prominence_find_s_wave(ecg_seg, weight_minima, current_wave, max_qrs_interval)
+            _prominence_find_p_wave(local_maxima, weight_maxima, current_wave, max_pr_interval)
+            _prominence_find_t_wave(local_extrema, (weight_minima + weight_maxima), current_wave, typical_st_segment)
+            _prominence_find_on_offsets(
+                ecg_seg,
+                sampling_rate,
+                local_minima,
+                current_wave,
+                max_p_basepoint_interval,
+                max_r_basepoint_interval,
+                max_t_basepoint_interval,
+            )
+
+        # append waves for current beat / complex
+        for key in waves:
+            if key == "ECG_R_Peaks":
+                waves[key].append(int(rpeaks[i]))
+            elif key in current_wave:
+                waves[key].append(int(current_wave[key] + left))
+            else:
+                waves[key].append(np.nan)
+
+    return waves
+
+
+def _calc_prominence(peaks, sig, Rpeak=None, minima=False):
+    """Returns an array of the same length as sig with prominences computed for the provided peaks.
+
+    Prominence of the R-peak is excluded if the R-peak position is given.
+
+    """
+    w = np.zeros_like(sig)
+
+    if len(peaks) < 1:
+        return w
+    # get prominence
+    _sig = -sig if minima else sig
+    w[peaks] = scipy.signal.peak_prominences(_sig, peaks)[0]
+    # optional: set rpeak prominence to zero to emphasize other peaks
+    if Rpeak is not None:
+        w[Rpeak] = 0
+    return w
+
+
+def _prominence_find_q_wave(weight_minima, current_wave, max_r_rise_time):
+    if "ECG_R_Peaks" not in current_wave:
+        return
+    q_bound = max(current_wave["ECG_R_Peaks"] - max_r_rise_time, 0)
+
+    current_wave["ECG_Q_Peaks"] = np.argmax(weight_minima[q_bound : current_wave["ECG_R_Peaks"]]) + q_bound
+
+
+def _prominence_find_s_wave(sig, weight_minima, current_wave, max_qrs_interval):
+    if "ECG_Q_Peaks" not in current_wave:
+        return
+    s_bound = current_wave["ECG_Q_Peaks"] + max_qrs_interval
+    s_wave = np.argmax(weight_minima[current_wave["ECG_R_Peaks"] : s_bound] > 0) + current_wave["ECG_R_Peaks"]
+    current_wave["ECG_S_Peaks"] = (
+        np.argmin(sig[current_wave["ECG_R_Peaks"] : s_bound]) + current_wave["ECG_R_Peaks"]
+        if s_wave == current_wave["ECG_R_Peaks"]
+        else s_wave
+    )
+
+
+def _prominence_find_p_wave(local_maxima, weight_maxima, current_wave, max_pr_interval):
+    if "ECG_Q_Peaks" not in current_wave:
+        return
+    p_candidates = local_maxima[
+        (current_wave["ECG_Q_Peaks"] - max_pr_interval <= local_maxima) & (local_maxima <= current_wave["ECG_Q_Peaks"])
+    ]
+    if p_candidates.any():
+        current_wave["ECG_P_Peaks"] = p_candidates[np.argmax(weight_maxima[p_candidates])]
+
+
+def _prominence_find_t_wave(local_extrema, weight_extrema, current_wave, typical_st_segment):
+    if "ECG_S_Peaks" not in current_wave:
+        return
+    t_candidates = local_extrema[(current_wave["ECG_S_Peaks"] + typical_st_segment <= local_extrema)]
+    if t_candidates.any():
+        current_wave["ECG_T_Peaks"] = t_candidates[np.argmax(weight_extrema[t_candidates])]
+
+
+def _prominence_find_on_offsets(
+    sig,
+    sampling_rate,
+    local_minima,
+    current_wave,
+    max_p_basepoint_interval,
+    max_r_basepoint_interval,
+    max_t_basepoint_interval,
+):
+    if "ECG_P_Peaks" in current_wave:
+        _, p_on, p_off = scipy.signal.peak_prominences(
+            sig, [current_wave["ECG_P_Peaks"]], wlen=max_p_basepoint_interval
+        )
+        if not np.isnan(p_on):
+            current_wave["ECG_P_Onsets"] = p_on[0]
+        if not np.isnan(p_off):
+            current_wave["ECG_P_Offsets"] = p_off[0]
+
+    if "ECG_T_Peaks" in current_wave:
+        p = -1 if np.isin(current_wave["ECG_T_Peaks"], local_minima) else 1
+
+        _, t_on, t_off = scipy.signal.peak_prominences(
+            p * sig, [current_wave["ECG_T_Peaks"]], wlen=max_t_basepoint_interval
+        )
+        if not np.isnan(t_on):
+            current_wave["ECG_T_Onsets"] = t_on[0]
+        if not np.isnan(t_off):
+            current_wave["ECG_T_Offsets"] = t_off[0]
+
+    # correct R-peak position towards local maxima (otherwise prominence will be falsely computed)
+    r_pos = _correct_peak(sig, sampling_rate, current_wave["ECG_R_Peaks"])
+    _, r_on, r_off = scipy.signal.peak_prominences(sig, [r_pos], wlen=max_r_basepoint_interval)
+    if not np.isnan(r_on):
+        current_wave["ECG_R_Onsets"] = r_on[0]
+
+    if not np.isnan(r_off):
+        current_wave["ECG_R_Offsets"] = r_off[0]
+
+
+def _correct_peak(sig, fs, peak, window=0.02):
+    """Correct peak towards local maxima within provided window."""
+
+    left = peak - int(window * fs)
+    right = peak + int(window * fs)
+    if len(sig[left:right]) > 0:
+        return np.argmax(sig[left:right]) + left
+    else:
+        return peak
+
+
 # Internals
 # ---------------------
 
 
 def _onset_offset_delineator(ecg, peaks, peak_type="rpeaks", sampling_rate=1000):
-    # Try loading pywt
-    try:
-        import pywt
-    except ImportError:
-        raise ImportError(
-            "NeuroKit error: ecg_delineator(): the 'PyWavelets' module is required for this",
-            "method to run. ",
-            "Please install it first (`pip install PyWavelets`).",
-        )
+
     # first derivative of the Gaissian signal
     scales = np.array([1, 2, 4, 8, 16])
     cwtmatr, __ = pywt.cwt(ecg, scales, "gaus1", sampling_period=1.0 / sampling_rate)
@@ -754,12 +998,12 @@ def _onset_offset_delineator(ecg, peaks, peak_type="rpeaks", sampling_rate=1000)
                 epsilon_onset = 0.25 * wt_peaks_data["peak_heights"][-1]
             leftbase = wt_peaks_data["left_bases"][-1] + index_peak - half_wave_width
             if peak_type == "rpeaks":
-                candidate_onsets = (
-                    np.where(cwtmatr[2, nfirst - 100 : nfirst] < epsilon_onset)[0] + nfirst - 100
-                )
+                candidate_onsets = np.where(cwtmatr[2, nfirst - 100 : nfirst] < epsilon_onset)[0] + nfirst - 100
             elif peak_type in ["tpeaks", "ppeaks"]:
                 candidate_onsets = (
-                    np.where(-cwtmatr[4, nfirst - 100 : nfirst] < epsilon_onset)[0] + nfirst - 100
+                    np.where(-cwtmatr[4, nfirst - 100 : nfirst] < epsilon_onset)[0]
+                    + nfirst
+                    - 100
                 )
 
             candidate_onsets = candidate_onsets.tolist() + [leftbase]
@@ -799,11 +1043,13 @@ def _onset_offset_delineator(ecg, peaks, peak_type="rpeaks", sampling_rate=1000)
             rightbase = wt_peaks_data["right_bases"][0] + index_peak
             if peak_type == "rpeaks":
                 candidate_offsets = (
-                    np.where((-cwtmatr[2, nlast : nlast + 100]) < epsilon_offset)[0] + nlast
+                    np.where((-cwtmatr[2, nlast : nlast + 100]) < epsilon_offset)[0]
+                    + nlast
                 )
             elif peak_type in ["tpeaks", "ppeaks"]:
                 candidate_offsets = (
-                    np.where((cwtmatr[4, nlast : nlast + 100]) < epsilon_offset)[0] + nlast
+                    np.where((cwtmatr[4, nlast : nlast + 100]) < epsilon_offset)[0]
+                    + nlast
                 )
 
             candidate_offsets = candidate_offsets.tolist() + [rightbase]
@@ -818,14 +1064,7 @@ def _onset_offset_delineator(ecg, peaks, peak_type="rpeaks", sampling_rate=1000)
 
 
 def _peaks_delineator(ecg, rpeaks, sampling_rate=1000):
-    # Try loading pywt
-    try:
-        import pywt
-    except ImportError:
-        raise ImportError(
-            "NeuroKit error: ecg_delineator(): the 'PyWavelets' module is required for this method to run. ",
-            "Please install it first (`pip install PyWavelets`).",
-        )
+
     # first derivative of the Gaissian signal
     scales = np.array([1, 2, 4, 8, 16])
     cwtmatr, __ = pywt.cwt(ecg, scales, "gaus1", sampling_period=1.0 / sampling_rate)
@@ -840,13 +1079,17 @@ def _peaks_delineator(ecg, rpeaks, sampling_rate=1000):
         end = rpeaks[i + 1] - search_boundary
         search_window = cwtmatr[4, start:end]
         height = 0.25 * np.sqrt(np.mean(np.square(search_window)))
-        peaks_tp, heights_tp = scipy.signal.find_peaks(np.abs(search_window), height=height)
+        peaks_tp, heights_tp = scipy.signal.find_peaks(
+            np.abs(search_window), height=height
+        )
         peaks_tp = peaks_tp + rpeaks[i] + search_boundary
         # set threshold for heights of peaks to find significant peaks in wavelet
         threshold = 0.125 * max(search_window)
         significant_peaks_tp = []
         significant_peaks_tp = [
-            peaks_tp[j] for j in range(len(peaks_tp)) if heights_tp["peak_heights"][j] > threshold
+            peaks_tp[j]
+            for j in range(len(peaks_tp))
+            if heights_tp["peak_heights"][j] > threshold
         ]
 
         significant_peaks_groups.append(
@@ -861,14 +1104,7 @@ def _peaks_delineator(ecg, rpeaks, sampling_rate=1000):
 
 
 def _find_tppeaks(ecg, keep_tp, sampling_rate=1000):
-    # Try loading pywt
-    try:
-        import pywt
-    except ImportError:
-        raise ImportError(
-            "NeuroKit error: ecg_delineator(): the 'PyWavelets' module is required for this method to run. ",
-            "Please install it first (`pip install PyWavelets`).",
-        )
+
     # first derivative of the Gaissian signal
     scales = np.array([1, 2, 4, 8, 16])
     cwtmatr, __ = pywt.cwt(ecg, scales, "gaus1", sampling_period=1.0 / sampling_rate)
@@ -883,12 +1119,13 @@ def _find_tppeaks(ecg, keep_tp, sampling_rate=1000):
         #    if near and correct_sign:
         if correct_sign:
             index_zero_cr = (
-                signal_zerocrossings(cwtmatr[4, :][index_cur : index_next + 1])[0] + index_cur
+                signal_zerocrossings(cwtmatr[4, :][index_cur : index_next + 1])[0]
+                + index_cur
             )
             nb_idx = int(max_search_duration * sampling_rate)
-            index_max = np.argmax(ecg[index_zero_cr - nb_idx : index_zero_cr + nb_idx]) + (
-                index_zero_cr - nb_idx
-            )
+            index_max = np.argmax(
+                ecg[index_zero_cr - nb_idx : index_zero_cr + nb_idx]
+            ) + (index_zero_cr - nb_idx)
             tppeaks.append(index_max)
     if len(tppeaks) == 0:
         tppeaks = [np.nan]
@@ -899,7 +1136,6 @@ def _find_tppeaks(ecg, keep_tp, sampling_rate=1000):
 #                              PEAK METHOD
 # =============================================================================
 def _ecg_delineator_peak(ecg, rpeaks=None, sampling_rate=1000):
-
     # Initialize
     heartbeats = ecg_segment(ecg, rpeaks, sampling_rate)
 
@@ -915,7 +1151,9 @@ def _ecg_delineator_peak(ecg, rpeaks=None, sampling_rate=1000):
         heartbeat = heartbeats[str(i + 1)]
 
         # Get index of heartbeat
-        R = heartbeat.index.get_loc(np.min(heartbeat.index.values[heartbeat.index.values > 0]))
+        R = heartbeat.index.get_loc(
+            np.min(heartbeat.index.values[heartbeat.index.values > 0])
+        )
 
         # Peaks ------
         # Q wave
@@ -947,11 +1185,6 @@ def _ecg_delineator_peak(ecg, rpeaks=None, sampling_rate=1000):
         "ECG_T_Offsets": T_offsets,
     }
 
-    # Ensure that all indices are not larger than ECG signal indices
-    for _, value in info.items():
-        if value[-1] >= len(ecg):
-            value[-1] = np.nan
-
     # Return info dictionary
     return info
 
@@ -961,7 +1194,7 @@ def _ecg_delineator_peak(ecg, rpeaks=None, sampling_rate=1000):
 
 
 def _ecg_delineator_peak_Q(rpeak, heartbeat, R):
-    segment = heartbeat[:0]  # Select left hand side
+    segment = heartbeat.loc[:0]  # Select left hand side
 
     Q = signal_findpeaks(
         -1 * segment["Signal"],
@@ -980,7 +1213,8 @@ def _ecg_delineator_peak_P(rpeak, heartbeat, R, Q):
 
     segment = heartbeat.iloc[:Q]  # Select left of Q wave
     P = signal_findpeaks(
-        segment["Signal"], height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min())
+        segment["Signal"],
+        height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min()),
     )
 
     if len(P["Peaks"]) == 0:
@@ -991,9 +1225,10 @@ def _ecg_delineator_peak_P(rpeak, heartbeat, R, Q):
 
 
 def _ecg_delineator_peak_S(rpeak, heartbeat):
-    segment = heartbeat[0:]  # Select right hand side
+    segment = heartbeat.loc[0:]  # Select right hand side
     S = signal_findpeaks(
-        -segment["Signal"], height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min())
+        -segment["Signal"],
+        height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min()),
     )
 
     if len(S["Peaks"]) == 0:
@@ -1008,7 +1243,8 @@ def _ecg_delineator_peak_T(rpeak, heartbeat, R, S):
 
     segment = heartbeat.iloc[R + S :]  # Select right of S wave
     T = signal_findpeaks(
-        segment["Signal"], height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min())
+        segment["Signal"],
+        height_min=0.05 * (segment["Signal"].max() - segment["Signal"].min()),
     )
 
     if len(T["Peaks"]) == 0:
@@ -1069,8 +1305,8 @@ def _ecg_delineate_plot(
     sampling_rate=1000,
     window_start=-0.35,
     window_end=0.55,
+    **kwargs
 ):
-
     """
     import neurokit2 as nk
     import numpy as np
@@ -1155,7 +1391,9 @@ def _ecg_delineate_plot(
         ax.plot(epoch_data.Time, epoch_data.Signal, color="grey", alpha=0.2)
     for i, feature_type in enumerate(features.columns.values):  # pylint: disable=W0612
         event_data = data[data[feature_type] == 1.0]
-        ax.scatter(event_data.Time, event_data.Signal, label=feature_type, alpha=0.5, s=200)
+        ax.scatter(
+            event_data.Time, event_data.Signal, label=feature_type, alpha=0.5, s=200
+        )
         ax.legend()
     return fig
 
@@ -1188,5 +1426,7 @@ def _calculate_abs_z(df, columns):
     """This function helps to calculate the absolute standardized distance between R-peaks and other delineated waves
     features by `ecg_delineate()`"""
     for column in columns:
-        df["Dist_R_" + column] = np.abs(standardize(df[column].sub(df["ECG_R_Peaks"], axis=0)))
+        df["Dist_R_" + column] = np.abs(
+            standardize(df[column].sub(df["ECG_R_Peaks"], axis=0))
+        )
     return df
