@@ -8,21 +8,36 @@ from ..epochs import epochs_to_df
 from ..misc import NeuroKitWarning
 from ..signal import signal_interpolate
 from ..signal.signal_power import signal_power
+from ..signal.signal_quality import signal_quality
 from ..stats import distance, rescale
 from .ecg_peaks import ecg_peaks
 from .ecg_segment import ecg_segment
 
 
-def ecg_quality(ecg_cleaned, rpeaks=None, sampling_rate=1000, method="averageQRS", approach=None):
+def ecg_quality(
+    ecg_cleaned, rpeaks=None, sampling_rate=1000, method="averageQRS", approach=None
+):
     """**ECG Signal Quality Assessment**
 
     Assess the quality of the ECG Signal using various methods:
 
+    * The ``"templatematch"`` method (loosely based on Orphanidou et al., 2015) computes a continuous
+      index of quality of the ECG signal, by calculating the correlation coefficient between each
+      individual beat morphology and an average (template) beat morphology. This index is therefore
+      relative: 1 corresponds to individual beats that are closest to the beat morphology (i.e.
+      correlate exactly with it) and 0 corresponds to there being no correlation with the average
+      beat morphology. For comparison, the ``"averageQRS"`` method forces the signal the quality to
+      vary between 0 (lowest) and 1 (highest). Therefore, even in a high quality signal, some beats will
+      have low values (e.g. 0), whereas others will have high values (e.g. 1). In contrast, ``"templatematch"``
+      computes a quality metric determined by the average of the correlations between the template beat morphology
+      and each individual beat's morphology. Therefore, it is possible that all beats exhibit high values (e.g. >0.95),
+      indicative of consistent beat morphologies across the signal.
+
     * The ``"averageQRS"`` method computes a continuous index of quality of the ECG signal, by
       interpolating the distance of each QRS segment from the average QRS segment present in the *
       data. This index is therefore relative: 1 corresponds to heartbeats that are the closest to
       the average sample and 0 corresponds to the most distant heartbeat from that average sample.
-      Note that 1 does not necessarily means "good": if the majority of samples are bad, than being
+      Note that 1 does not necessarily means "good": if the majority of samples are bad, then being
       close to the average will likely mean bad as well. Use this index with care and plot it
       alongside your ECG signal to see if it makes sense.
 
@@ -55,18 +70,20 @@ def ecg_quality(ecg_cleaned, rpeaks=None, sampling_rate=1000, method="averageQRS
     -------
     array or str
         Vector containing the quality index ranging from 0 to 1 for ``"averageQRS"`` method,
-        returns string classification (``Unacceptable``, ``Barely Acceptable`` or ``Excellent``)
-        of the signal for ``"zhao2018 method"``.
+        returns string classification (``Unacceptable``, ``Barely acceptable`` or ``Excellent``)
+        of the signal for ``"zhao2018"`` method.
 
     See Also
     --------
-    ecg_segment, ecg_delineate
+    ecg_segment, ecg_delineate, signal_quality
 
     References
     ----------
     * Zhao, Z., & Zhang, Y. (2018). "SQI quality evaluation mechanism of single-lead ECG signal
       based on simple heuristic fusion and fuzzy comprehensive evaluation". Frontiers in
       Physiology, 9, 727.
+    * Orphanidou, C. et al. (2015). "Signal-quality indices for the electrocardiogram and photoplethysmogram:
+      derivation and applications to wireless monitoring". IEEE Journal of Biomedical and Health Informatics, 19(3), 832-8.
 
     Examples
     --------
@@ -98,9 +115,11 @@ def ecg_quality(ecg_cleaned, rpeaks=None, sampling_rate=1000, method="averageQRS
 
     method = method.lower()  # remove capitalised letters
 
-    # Run peak detection algorithm
+    # Run quality assessment algorithm
     if method in ["averageqrs"]:
-        quality = _ecg_quality_averageQRS(ecg_cleaned, rpeaks=rpeaks, sampling_rate=sampling_rate)
+        quality = _ecg_quality_averageQRS(
+            ecg_cleaned, rpeaks=rpeaks, sampling_rate=sampling_rate
+        )
     elif method in ["zhao2018", "zhao", "SQI"]:
         if approach is None:
             approach = "simple"
@@ -115,6 +134,19 @@ def ecg_quality(ecg_cleaned, rpeaks=None, sampling_rate=1000, method="averageQRS
         quality = _ecg_quality_zhao2018(
             ecg_cleaned, rpeaks=rpeaks, sampling_rate=sampling_rate, mode=approach
         )
+    elif method in ["templatematch", "orphanidou2015"]:
+        # Detect R peaks (if not done already)
+        if rpeaks is None:
+            _, rpeaks = ecg_peaks(ecg_cleaned, sampling_rate=sampling_rate)
+            rpeaks = rpeaks["ECG_R_Peaks"]
+        # Assess quality using template matching
+        quality = signal_quality(
+            ecg_cleaned,
+            beat_inds=rpeaks,
+            signal_type="ecg",
+            sampling_rate=sampling_rate,
+            method="templatematch",
+        )
 
     return quality
 
@@ -123,7 +155,6 @@ def ecg_quality(ecg_cleaned, rpeaks=None, sampling_rate=1000, method="averageQRS
 # Average QRS method
 # =============================================================================
 def _ecg_quality_averageQRS(ecg_cleaned, rpeaks=None, sampling_rate=1000):
-
     # Sanitize inputs
     if rpeaks is None:
         _, rpeaks = ecg_peaks(ecg_cleaned, sampling_rate=sampling_rate)
@@ -131,7 +162,9 @@ def _ecg_quality_averageQRS(ecg_cleaned, rpeaks=None, sampling_rate=1000):
 
     # Get heartbeats
     heartbeats = ecg_segment(ecg_cleaned, rpeaks, sampling_rate)
-    data = epochs_to_df(heartbeats).pivot(index="Label", columns="Time", values="Signal")
+    data = epochs_to_df(heartbeats).pivot(
+        index="Label", columns="Time", values="Signal"
+    )
     data.index = data.index.astype(int)
     data = data.sort_index()
 
@@ -152,7 +185,7 @@ def _ecg_quality_averageQRS(ecg_cleaned, rpeaks=None, sampling_rate=1000):
 
     # Interpolate
     quality = signal_interpolate(
-        rpeaks, quality, x_new=np.arange(len(ecg_cleaned)), method="quadratic"
+        rpeaks, quality, x_new=np.arange(len(ecg_cleaned)), method="previous"
     )
 
     return quality
@@ -213,8 +246,12 @@ def _ecg_quality_zhao2018(
 
     # Compute indexes
     kSQI = _ecg_quality_kSQI(ecg_cleaned, method=kurtosis_method)
-    pSQI = _ecg_quality_pSQI(ecg_cleaned, sampling_rate=sampling_rate, window=window, **kwargs)
-    basSQI = _ecg_quality_basSQI(ecg_cleaned, sampling_rate=sampling_rate, window=window, **kwargs)
+    pSQI = _ecg_quality_pSQI(
+        ecg_cleaned, sampling_rate=sampling_rate, window=window, **kwargs
+    )
+    basSQI = _ecg_quality_basSQI(
+        ecg_cleaned, sampling_rate=sampling_rate, window=window, **kwargs
+    )
 
     # Classify indices based on simple heuristic fusion
     if mode == "simple":
@@ -336,7 +373,9 @@ def _ecg_quality_zhao2018(
         # W = np.array([0.4, 0.4, 0.1, 0.1])
         W = np.array([0.6, 0.2, 0.2])
 
-        S = np.array([np.sum((R[:, 0] * W)), np.sum((R[:, 1] * W)), np.sum((R[:, 2] * W))])
+        S = np.array(
+            [np.sum((R[:, 0] * W)), np.sum((R[:, 1] * W)), np.sum((R[:, 2] * W))]
+        )
 
         # classify
         V = np.sum(np.power(S, 2) * [1, 2, 3]) / np.sum(np.power(S, 2))
@@ -378,8 +417,8 @@ def _ecg_quality_pSQI(
         **kwargs
     )
 
-    num_power = psd.iloc[0][0]
-    dem_power = psd.iloc[0][1]
+    num_power = psd.iloc[0, 0]
+    dem_power = psd.iloc[0, 1]
 
     return num_power / dem_power
 
@@ -403,7 +442,7 @@ def _ecg_quality_basSQI(
         **kwargs
     )
 
-    num_power = psd.iloc[0][0]
-    dem_power = psd.iloc[0][1]
+    num_power = psd.iloc[0, 0]
+    dem_power = psd.iloc[0, 1]
 
-    return 1 - num_power / dem_power
+    return (1 - num_power) / dem_power
