@@ -5,13 +5,23 @@ import numpy as np
 import pandas as pd
 import scipy.signal
 
-from ..misc import as_vector, NeuroKitWarning
+from ..misc import NeuroKitWarning, as_vector
 from ..signal import signal_filter, signal_smooth
 
 
 def eda_clean(eda_signal, sampling_rate=1000, method="neurokit"):
     """**Preprocess Electrodermal Activity (EDA) signal**
 
+    This function cleans the EDA signal by removing noise and smoothing the signal with different methods.
+
+    * **NeuroKit**: Default methods. Low-pass filter with a 3 Hz cutoff frequency and a 4th order
+      Butterworth filter. Note thaht if the sampling rate is lower than 7 Hz (as it is the case
+      with some signals recorded by wearables such as Empatica), the filtering is skipped (as there
+      is no high enough frequency to remove).
+    * **BioSPPy**: More aggresive filtering than NeuroKit's default method. Low-pass filter with a
+      5 Hz cutoff frequency and a 4th order Butterworth filter.
+
+
     Parameters
     ----------
     eda_signal : Union[list, np.array, pd.Series]
@@ -19,7 +29,8 @@ def eda_clean(eda_signal, sampling_rate=1000, method="neurokit"):
     sampling_rate : int
         The sampling frequency of `rsp_signal` (in Hz, i.e., samples/second).
     method : str
-        The processing pipeline to apply. Can be one of ``"neurokit"`` (default) or ``"biosppy"``.
+        The processing pipeline to apply. Can be one of ``"neurokit"`` (default), ``"biosppy"``, or
+        ``"none"``.
 
     Returns
     -------
@@ -37,13 +48,15 @@ def eda_clean(eda_signal, sampling_rate=1000, method="neurokit"):
       import pandas as pd
       import neurokit2 as nk
 
-      eda = nk.eda_simulate(duration=30, sampling_rate=100, scr_number=10, noise=0.01, drift=0.02)
-      signals = pd.DataFrame({"EDA_Raw": eda,
-                              "EDA_BioSPPy": nk.eda_clean(eda, sampling_rate=100,method='biosppy'),
-                              "EDA_NeuroKit": nk.eda_clean(eda, sampling_rate=100,
-                              method='neurokit')})
+      # Simulate raw signal
+      eda = nk.eda_simulate(duration=15, sampling_rate=100, scr_number=10, noise=0.01, drift=0.02)
+
+      # Clean
+      eda_clean1 = nk.eda_clean(eda, sampling_rate=100, method='neurokit')
+      eda_clean2 = nk.eda_clean(eda, sampling_rate=100, method='biosppy')
+
       @savefig p_eda_clean.png scale=100%
-      fig = signals.plot()
+      nk.signal_plot([eda, eda_clean1, eda_clean2], labels=["Raw", "NeuroKit", "BioSPPy"])
       @suppress
       plt.close()
 
@@ -56,7 +69,7 @@ def eda_clean(eda_signal, sampling_rate=1000, method="neurokit"):
         warn(
             "There are " + str(n_missing) + " missing data points in your signal."
             " Filling missing values by using the forward filling method.",
-            category=NeuroKitWarning
+            category=NeuroKitWarning,
         )
         eda_signal = _eda_clean_missing(eda_signal)
 
@@ -65,6 +78,8 @@ def eda_clean(eda_signal, sampling_rate=1000, method="neurokit"):
         clean = _eda_clean_biosppy(eda_signal, sampling_rate)
     elif method in ["default", "neurokit", "nk"]:
         clean = _eda_clean_neurokit(eda_signal, sampling_rate)
+    elif method is None or method == "none":
+        clean = eda_signal
     else:
         raise ValueError("NeuroKit error: eda_clean(): 'method' should be one of 'biosppy'.")
 
@@ -80,13 +95,23 @@ def _eda_clean_missing(eda_signal):
 
     return eda_signal
 
+
 # =============================================================================
 # NK
 # =============================================================================
 def _eda_clean_neurokit(eda_signal, sampling_rate=1000):
 
+    if sampling_rate <= 6:
+        warn(
+            "EDA signal is sampled at very low frequency. Skipping filtering.",
+            category=NeuroKitWarning,
+        )
+        return eda_signal
+
     # Filtering
-    filtered = signal_filter(eda_signal, sampling_rate=sampling_rate, highcut=3, method="butterworth", order=4)
+    filtered = signal_filter(
+        eda_signal, sampling_rate=sampling_rate, highcut=3, method="butterworth", order=4
+    )
 
     return filtered
 
@@ -103,13 +128,17 @@ def _eda_clean_biosppy(eda_signal, sampling_rate=1000):
     # Parameters
     order = 4
     frequency = 5
-    frequency = 2 * np.array(frequency) / sampling_rate  # Normalize frequency to Nyquist Frequency (Fs/2).
+    frequency = (
+        2 * np.array(frequency) / sampling_rate
+    )  # Normalize frequency to Nyquist Frequency (Fs/2).
 
     # Filtering
     b, a = scipy.signal.butter(N=order, Wn=frequency, btype="lowpass", analog=False, output="ba")
     filtered = scipy.signal.filtfilt(b, a, eda_signal)
 
     # Smoothing
-    clean = signal_smooth(filtered, method="convolution", kernel="boxzen", size=int(0.75 * sampling_rate))
+    clean = signal_smooth(
+        filtered, method="convolution", kernel="boxzen", size=int(0.75 * sampling_rate)
+    )
 
     return clean
