@@ -5,29 +5,29 @@ from ..signal.signal_formatpeaks import _signal_formatpeaks_sanitize
 
 
 def eda_fixpeaks(peaks, onsets=None, height=None):
-    """Correct  Skin Conductance Responses (SCR) peaks.
+    """**Correct  Skin Conductance Responses (SCR) peaks**
 
-    Low-level function used by `eda_peaks()` to correct the peaks found by `eda_findpeaks()`.
-    Doesn't do anything for now for EDA. See `eda_peaks()` for details.
+    Low-level function used by ``"eda_peaks()"`` to correct the peaks found by
+    ``"eda_findpeaks()"``. Doesn't do anything for now for EDA. See :func:`eda_peaks` for details.
 
     Parameters
     ----------
     peaks : list or array or DataFrame or Series or dict
         The samples at which the SCR peaks occur. If a dict or a DataFrame is passed,
-        it is assumed that these containers were obtained with `eda_findpeaks()`.
+        it is assumed that these containers were obtained with ``"eda_findpeaks()"``.
     onsets : list or array or DataFrame or Series or dict
         The samples at which the SCR onsets occur. If a dict or a DataFrame is passed,
-        it is assumed that these containers were obtained with `eda_findpeaks()`. Defaults to None.
+        it is assumed that these containers were obtained with ``"eda_findpeaks()"``. Defaults to None.
     height : list or array or DataFrame or Series or dict
         The samples at which the amplitude of the SCR peaks occur. If a dict or a DataFrame is
-        passed, it is assumed that these containers were obtained with `eda_findpeaks()`. Defaults to None.
+        passed, it is assumed that these containers were obtained with ``"eda_findpeaks()"``. Defaults to None.
 
     Returns
     -------
     info : dict
-        A dictionary containing additional information, in this case the aplitude of the SCR, the samples
-        at which the SCR onset and the SCR peaks occur. Accessible with the keys "SCR_Amplitude",
-        "SCR_Onsets", and "SCR_Peaks" respectively.
+        A dictionary containing additional information, in this case the aplitude of the SCR, the
+        samples at which the SCR onset and the SCR peaks occur. Accessible with the keys
+        ``"SCR_Amplitude"``, ``"SCR_Onsets"``, and ``"SCR_Peaks"`` respectively.
 
     See Also
     --------
@@ -37,20 +37,24 @@ def eda_fixpeaks(peaks, onsets=None, height=None):
 
     Examples
     ---------
-    >>> import neurokit2 as nk
-    >>>
-    >>> # Get phasic component
-    >>> eda_signal = nk.eda_simulate(duration=30, scr_number=5, drift=0.1, noise=0)
-    >>> eda_cleaned = nk.eda_clean(eda_signal)
-    >>> eda = nk.eda_phasic(eda_cleaned)
-    >>> eda_phasic = eda["EDA_Phasic"].values
-    >>>
-    >>> # Find and fix peaks
-    >>> info = nk.eda_findpeaks(eda_phasic)
-    >>> info = nk.eda_fixpeaks(info)
-    >>>
-    >>> fig = nk.events_plot(info["SCR_Peaks"], eda_phasic)
-    >>> fig #doctest: +SKIP
+    .. ipython:: python
+
+      import neurokit2 as nk
+
+      # Get phasic component
+      eda_signal = nk.eda_simulate(duration=30, scr_number=5, drift=0.1, noise=0)
+      eda_cleaned = nk.eda_clean(eda_signal)
+      eda = nk.eda_phasic(eda_cleaned)
+      eda_phasic = eda["EDA_Phasic"].values
+
+      # Find and fix peaks
+      info = nk.eda_findpeaks(eda_phasic)
+      info = nk.eda_fixpeaks(info)
+
+      @savefig p_eda_fixpeaks.png scale=100%
+      nk.events_plot(info["SCR_Peaks"], eda_phasic)
+      @suppress
+      plt.close()
 
     """
     # Format input.
