@@ -5,6 +5,7 @@ from .eeg_diss import eeg_diss
 from .eeg_gfp import eeg_gfp
 from .eeg_power import eeg_power
 from .eeg_rereference import eeg_rereference
+from .eeg_simulate import eeg_simulate
 from .eeg_source import eeg_source
 from .eeg_source_extract import eeg_source_extract
 from .mne_channel_add import mne_channel_add
@@ -22,6 +23,7 @@ __all__ = [
     "mne_to_df",
     "mne_to_dict",
     "mne_templateMRI",
+    "eeg_simulate",
     "eeg_source",
     "eeg_source_extract",
     "eeg_power",
