@@ -31,15 +31,13 @@ def emg_eventrelated(epochs, silent=False):
         by the `Label` column (if not present, by the `Index` column). The analyzed features consist
         of the following:
 
-            * ``"EMG_Activation*``: indication of whether there is muscular activation following
-              the onset of the event (1 if present, 0 if absent) and if so, its corresponding
-              amplitude features and the number of activations in each epoch. If there is no
-              activation, nans are displayed for the below features.
-            * ``"EMG_Amplitude_Mean*``: the mean amplitude of the activity.
-            * ``"EMG_Amplitude_Max*``: the maximum amplitude of the activity.
-            * ``"EMG_Amplitude_SD*``: the standard deviation of the activity amplitude.
-            * ``"EMG_Amplitude_Max_Time*``: the time of maximum amplitude.
-            * ``"EMG_Bursts*``: the number of activations, or bursts of activity, within each epoch.
+        .. codebookadd::
+            EMG_Activation|Indication of whether there is muscular activation following.
+            EMG_Amplitude_Mean|The mean amplitude of the activity.
+            EMG_Amplitude_Max|The maximum amplitude of the activity.
+            EMG_Amplitude_SD|The standard deviation of the activity amplitude.
+            EMG_Amplitude_Max_Time|The time of maximum amplitude.
+            EMG_Bursts|The number of activations, or bursts of activity, within each epoch.
 
     See Also
     --------
