@@ -1,9 +1,9 @@
 """Submodule for NeuroKit."""
 
+from .epochs_average import epochs_average
 from .epochs_create import epochs_create
 from .epochs_plot import epochs_plot
 from .epochs_to_array import epochs_to_array
 from .epochs_to_df import epochs_to_df
 
-
-__all__ = ["epochs_create", "epochs_to_df", "epochs_to_array", "epochs_plot"]
+__all__ = ["epochs_create", "epochs_to_df", "epochs_to_array", "epochs_average", "epochs_plot"]
