@@ -113,6 +113,15 @@ def epochs_create(
       # Chunk into n blocks of 1 second
       epochs = nk.epochs_create(data, sampling_rate=100, epochs_end=1)
 
+    * **Example 5**: Epochs with list of starting points
+
+    .. ipython:: python
+
+      epochs = nk.epochs_create(data, events, sampling_rate=100,
+                                epochs_start=[0, -1, -1, 0],
+                                epochs_end=[1, 0, 0, 1])
+      [len(epochs[i]) for i in epochs.keys()]
+
     """
 
     # Santize data input
@@ -130,7 +139,9 @@ def epochs_create(
         events = np.linspace(0, len(data), events + 2)[1:-1]
     if isinstance(events, dict) is False:
         events = _events_find_label(
-            {"onset": events}, event_labels=event_labels, event_conditions=event_conditions
+            {"onset": events},
+            event_labels=event_labels,
+            event_conditions=event_conditions,
         )
 
     event_onsets = list(events["onset"])
@@ -153,7 +164,9 @@ def epochs_create(
     )
 
     # Find the maximum numbers of samples in an epoch
-    parameters["duration"] = list(np.array(parameters["end"]) - np.array(parameters["start"]))
+    parameters["duration"] = list(
+        np.array(parameters["end"]) - np.array(parameters["start"])
+    )
     epoch_max_duration = int(max((i * sampling_rate for i in parameters["duration"])))
 
     # Extend data by the max samples in epochs * NaN (to prevent non-complete data)
@@ -164,7 +177,7 @@ def epochs_create(
         dtype=data.dtypes
     )
     # Only then, we convert the non-integers to nans (because regular numpy's ints cannot be nan)
-    buffer.select_dtypes(exclude="int64").replace({0.0: np.nan}, inplace=True)
+    buffer.select_dtypes(exclude=["int", "int64"]).replace({0.0: np.nan}, inplace=True)
     # Now we can combine the buffer with the data
     data = pd.concat([buffer, data, buffer], ignore_index=True, sort=False)
 
@@ -173,7 +186,6 @@ def epochs_create(
 
     epochs = {}
     for i, label in enumerate(parameters["label"]):
-
         # Find indices
         start = parameters["onset"][i] + (parameters["start"][i] * sampling_rate)
         end = parameters["onset"][i] + (parameters["end"][i] * sampling_rate)
@@ -184,7 +196,10 @@ def epochs_create(
         # Correct index
         epoch["Index"] = epoch.index.values - length_buffer
         epoch.index = np.linspace(
-            start=parameters["start"][i], stop=parameters["end"][i], num=len(epoch), endpoint=True
+            start=parameters["start"][i],
+            stop=parameters["end"][i],
+            num=len(epoch),
+            endpoint=True,
         )
 
         if baseline_correction is True:
@@ -201,9 +216,7 @@ def epochs_create(
 
     # Sanitize dtype of individual columns
     for i in epochs:
-
         for colname, column in epochs[i].select_dtypes(include=["object"]).items():
-
             # Check whether columns are indices or label/condition
             values = column.unique().tolist()
             zero_or_one = not (False in [x in [0, 1] for x in values])
