@@ -4,7 +4,7 @@ import matplotlib.pyplot as plt
 from .epochs_to_df import epochs_to_df
 
 
-def epochs_plot(epochs, legend=True, **kwargs):
+def epochs_plot(epochs, legend=True, columns="all", **kwargs):
     """**Epochs visualization**
 
     Plot epochs.
@@ -15,6 +15,8 @@ def epochs_plot(epochs, legend=True, **kwargs):
         A dict containing one DataFrame per event/trial. Usually obtained via `epochs_create()`.
     legend : bool
         Display the legend (the key of each epoch).
+    columns : str or list
+        Which columns to plot. If 'all', plot all columns. If a list, plot only the columns in the list.
     **kwargs
         Other arguments to pass (not used for now).
 
@@ -34,10 +36,10 @@ def epochs_plot(epochs, legend=True, **kwargs):
       events = nk.events_find(data["Photosensor"],
                               threshold_keep='below',
                               event_conditions=["Negative", "Neutral", "Neutral", "Negative"])
-      epochs = nk.epochs_create(data, events, sampling_rate=100, epochs_end=1)
+      epochs = nk.epochs_create(data, events, sampling_rate=100, epochs_end=7)
 
       @savefig p_epochs_plot1.png scale=100%
-      nk.epochs_plot(epochs)
+      nk.epochs_plot(epochs, columns=["EDA", "RSP"])
       @suppress
       plt.close()
 
@@ -79,6 +81,10 @@ def epochs_plot(epochs, legend=True, **kwargs):
 
     cols = data.columns.values
     cols = [x for x in cols if x not in ["Time", "Condition", "Label", "Index"]]
+    if columns != "all":
+        if isinstance(columns, str):
+            columns = [columns]
+        cols = [x for x in cols if x in columns]
 
     if len(cols) == 1:
         fig, ax = plt.subplots()
@@ -98,14 +104,28 @@ def _epochs_mne_sanitize(epochs, what):
     """
 
     data = epochs.to_data_frame()
-    data = data.rename(columns={"time": "Time", "condition": "Condition", "epoch": "Label"})
+    data = data.rename(
+        columns={"time": "Time", "condition": "Condition", "epoch": "Label"}
+    )
     data["Time"] = data["Time"] / 1000  # ms to seconds
 
     if isinstance(what, str):
-        data = data[[x for x in data.columns.values if x in ["Time", "Condition", "Label", what]]]
+        data = data[
+            [
+                x
+                for x in data.columns.values
+                if x in ["Time", "Condition", "Label", what]
+            ]
+        ]
     # Select a few specified channels
     elif isinstance(what, list):
-        data = data[[x for x in data.columns.values if x in ["Time", "Condition", "Label"] + what]]
+        data = data[
+            [
+                x
+                for x in data.columns.values
+                if x in ["Time", "Condition", "Label"] + what
+            ]
+        ]
 
     return data
 
@@ -116,14 +136,25 @@ def _epochs_plot(data, ax, col, legend):
         grouped = data.groupby("Condition")
 
         # Colors
-        color_list = ["red", "blue", "green", "yellow", "purple", "orange", "cyan", "magenta"]
+        color_list = [
+            "red",
+            "blue",
+            "green",
+            "yellow",
+            "purple",
+            "orange",
+            "cyan",
+            "magenta",
+        ]
         colors = {}
         for i, cond in enumerate(set(data["Condition"])):
             colors[cond] = color_list[i]
 
         # Plot
         for key, group in grouped:
-            df = group.pivot_table(index="Time", columns=["Condition", "Label"], values=col)
+            df = group.pivot_table(
+                index="Time", columns=["Condition", "Label"], values=col
+            )
             df.plot(ax=ax, label=col, title=col, style=colors[key], legend=legend)
 
         # TODO: Custom legend
