@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-import matplotlib.cm
 import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
@@ -110,7 +109,7 @@ def events_plot(events, signal=None, color="red", linestyle="--"):
         signal = pd.DataFrame({"Signal": signal})
 
     # Plot signal(s)
-    signal.plot()
+    axs = signal.plot()
 
     # Check if events is list of lists
     try:
@@ -127,7 +126,7 @@ def events_plot(events, signal=None, color="red", linestyle="--"):
     else:
         # Convert color and style to list
         if isinstance(color, str):
-            color_map = matplotlib.cm.get_cmap("rainbow")
+            color_map = plt.get_cmap("rainbow")
             color = color_map(np.linspace(0, 1, num=len(events)))
         if isinstance(linestyle, str):
             linestyle = np.full(len(events), linestyle)
@@ -145,3 +144,5 @@ def events_plot(events, signal=None, color="red", linestyle="--"):
                 newLabels.append(label)
                 newHandles.append(handle)
         plt.legend(newHandles, newLabels)
+
+    return axs.get_figure()
