@@ -95,16 +95,15 @@ def hrv_rsa(
     rsa : dict
         A dictionary containing the RSA features, which includes:
 
-        * ``"RSA_P2T_Values"``: the estimate of RSA during each breath cycle, produced by
-          subtracting the shortest heart period (or RR interval) from the longest heart period in
-          ms.
-        * ``"RSA_P2T_Mean"``: the mean peak-to-trough across all cycles in ms
-        * ``"RSA_P2T_Mean_log"``: the logarithm of the mean of RSA estimates.
-        * ``"RSA_P2T_SD"``: the standard deviation of all RSA estimates.
-        * ``"RSA_P2T_NoRSA"``: the number of breath cycles
-          from which RSA could not be calculated.
-        * ``"RSA_PorgesBohrer"``: the Porges-Bohrer estimate of RSA, optimal
-          when the signal to noise ratio is low, in ``ln(ms^2)``.
+        .. codebookadd::
+            RSA_P2T_Values|The estimate of RSA during each breath cycle, produced by subtracting \
+                the shortest heart period (or RR interval) from the longest heart period in ms.
+            RSA_P2T_Mean|The mean peak-to-trough across all cycles in ms.
+            RSA_P2T_Mean_log|The logarithm of the mean of RSA estimates.
+            RSA_P2T_SD|The standard deviation of all RSA estimates.
+            RSA_P2T_NoRSA|The number of breath cycles from which RSA could not be calculated.
+            RSA_PorgesBohrer|The Porges-Bohrer estimate of RSA, optimal when the signal to noise \
+                ratio is low, in ln(ms^2).
 
     Example
     ----------
@@ -194,7 +193,7 @@ def hrv_rsa(
     else:
         warn(
             f"The duration of recording is shorter than the duration of the window ({window}"
-            "seconds). Returning RSA by Gates method as Nan. Consider using a longer recording.",
+            " seconds). Returning RSA by Gates method as Nan. Consider using a longer recording.",
             category=NeuroKitWarning,
         )
         if continuous is False:
@@ -237,7 +236,9 @@ def _hrv_rsa_p2t(
         cycles_rri_inh.append(
             rpeaks[np.logical_and(rpeaks >= cycle_init, rpeaks < rsp_peak_offset)]
         )
-        cycles_rri_exh.append(rpeaks[np.logical_and(rpeaks >= rsp_peak, rpeaks < cycle_end)])
+        cycles_rri_exh.append(
+            rpeaks[np.logical_and(rpeaks >= rsp_peak, rpeaks < cycle_end)]
+        )
 
     # Iterate over all cycles
     rsa_values = np.full(len(cycles_rri_exh), np.nan)
@@ -245,7 +246,9 @@ def _hrv_rsa_p2t(
         # Estimate of RSA during each breathing phase
         RRis_inh = np.diff(cycles_rri_inh[i]) / sampling_rate * 1000
         RRis_exh = np.diff(cycles_rri_exh[i]) / sampling_rate * 1000
-        if np.logical_and(len(RRis_inh) > 0, len(RRis_exh) > 0):  # you need at least one RRI
+        if np.logical_and(
+            len(RRis_inh) > 0, len(RRis_exh) > 0
+        ):  # you need at least one RRI
             rsa_value = np.max(RRis_exh) - np.min(RRis_inh)
             if rsa_value > 0:
                 # Take into consideration only rsp cycles in which the max exh > than min inh
@@ -258,7 +261,9 @@ def _hrv_rsa_p2t(
         rsa = {"RSA_P2T_Mean": np.nanmean(rsa_values)}
         rsa["RSA_P2T_Mean_log"] = np.log(rsa["RSA_P2T_Mean"])  # pylint: disable=E1111
         rsa["RSA_P2T_SD"] = np.nanstd(rsa_values, ddof=1)
-        rsa["RSA_P2T_NoRSA"] = len(pd.Series(rsa_values).index[pd.Series(rsa_values).isnull()])
+        rsa["RSA_P2T_NoRSA"] = len(
+            pd.Series(rsa_values).index[pd.Series(rsa_values).isnull()]
+        )
     else:
         rsa = signal_interpolate(
             x_values=rsp_peaks[~np.isnan(rsa_values)],
@@ -275,7 +280,9 @@ def _hrv_rsa_pb(ecg_period, sampling_rate, continuous=False):
         return None
 
     # Re-sample at 2 Hz
-    resampled = signal_resample(ecg_period, sampling_rate=sampling_rate, desired_sampling_rate=2)
+    resampled = signal_resample(
+        ecg_period, sampling_rate=sampling_rate, desired_sampling_rate=2
+    )
 
     # Fit 21-point cubic polynomial filter (zero mean, 3rd order)
     # with a low-pass cutoff frequency of 0.095Hz
@@ -291,7 +298,9 @@ def _hrv_rsa_pb(ecg_period, sampling_rate, continuous=False):
 
     zero_mean = resampled - trend
     # Remove variance outside bandwidth of spontaneous respiration
-    zero_mean_filtered = signal_filter(zero_mean, sampling_rate=2, lowcut=0.12, highcut=0.40)
+    zero_mean_filtered = signal_filter(
+        zero_mean, sampling_rate=2, lowcut=0.12, highcut=0.40
+    )
 
     # Divide into 30-second epochs
     time = np.arange(0, len(zero_mean_filtered)) / 2
@@ -380,9 +389,13 @@ def _hrv_rsa_pb(ecg_period, sampling_rate, continuous=False):
 
 
 def _hrv_rsa_gates(
-    ecg_signals, rpeaks, sampling_rate=1000, window=None, window_number=None, continuous=False
+    ecg_signals,
+    rpeaks,
+    sampling_rate=1000,
+    window=None,
+    window_number=None,
+    continuous=False,
 ):
-
     # Boundaries of rsa freq
     min_frequency = 0.12
     max_frequency = 0.40
@@ -394,7 +407,10 @@ def _hrv_rsa_gates(
     desired_sampling_rate = 4
 
     rri, rri_time, sampling_rate = intervals_process(
-        rri, intervals_time=rri_time, interpolate=True, interpolation_rate=desired_sampling_rate
+        rri,
+        intervals_time=rri_time,
+        interpolate=True,
+        interpolation_rate=desired_sampling_rate,
     )
 
     # Sanitize parameters
@@ -426,7 +442,9 @@ def _hrv_rsa_gates(
     # Sanitize output
     if continuous is False:
         rsa = {"RSA_Gates_Mean": np.nanmean(meanRSA)}
-        rsa["RSA_Gates_Mean_log"] = np.log(rsa["RSA_Gates_Mean"])  # pylint: disable=E1111
+        rsa["RSA_Gates_Mean_log"] = np.log(
+            rsa["RSA_Gates_Mean"]
+        )  # pylint: disable=E1111
         rsa["RSA_Gates_SD"] = np.nanstd(meanRSA, ddof=1)
     else:
         # For window=32, meanRSA is RSA from 16th second to xth second where x=recording
@@ -467,7 +485,8 @@ def _get_multipeak_window(nperseg, window_number=8):
     length = np.arange(1, nperseg).conj().transpose()
     r0 = 2 / C * (1 - np.exp(-C * B / 2))
     r_num = 2 * C - np.exp(-C * B / 2) * (
-        2 * C * np.cos(np.pi * B * length) - 4 * np.pi * length * np.sin(np.pi * B * length)
+        2 * C * np.cos(np.pi * B * length)
+        - 4 * np.pi * length * np.sin(np.pi * B * length)
     )
 
     r_den = C**2 + (2 * np.pi * length) ** 2
@@ -479,7 +498,8 @@ def _get_multipeak_window(nperseg, window_number=8):
     rbox = np.append(B, r)
 
     rpen = (
-        10 ** (K2 / 10) * np.append(1, np.zeros((nperseg - 1, 1))) - (10 ** (K2 / 10) - 1) * rbox
+        10 ** (K2 / 10) * np.append(1, np.zeros((nperseg - 1, 1)))
+        - (10 ** (K2 / 10) - 1) * rbox
     )  # Covariance function penalty function
 
     Ry = scipy.linalg.toeplitz(rpeak)
@@ -533,7 +553,6 @@ def _hrv_rsa_cycles(signals):
 
 
 def _hrv_rsa_formatinput(ecg_signals, rsp_signals, rpeaks=None, sampling_rate=1000):
-
     rpeaks, sampling_rate = _hrv_format_input(
         rpeaks, sampling_rate=sampling_rate, output_format="peaks"
     )
@@ -589,7 +608,9 @@ def _hrv_rsa_formatinput(ecg_signals, rsp_signals, rpeaks=None, sampling_rate=10
     else:
         rpeaks = _signal_formatpeaks_sanitize(rpeaks)
 
-    nonduplicates = ecg_signals.columns[[i not in rsp_signals.columns for i in ecg_signals.columns]]
+    nonduplicates = ecg_signals.columns[
+        [i not in rsp_signals.columns for i in ecg_signals.columns]
+    ]
     signals = pd.concat([ecg_signals[nonduplicates], rsp_signals], axis=1)
 
     return signals, ecg_period, rpeaks, sampling_rate
