@@ -70,12 +70,14 @@ def hrv_time(peaks, sampling_rate=1000, show=False, **kwargs):
         * **MCVNN**: The median absolute deviation of the RR intervals (**MadNN**) divided by the
           median of the RR intervals (**MedianNN**).
         * **IQRNN**: The interquartile range (**IQR**) of the RR intervals.
+        * **SDRMSSD**: SDNN / RMSSD, a time-domain equivalent for the low Frequency-to-High
+          Frequency (LF/HF) Ratio (Sollers et al., 2007).
         * **Prc20NN**: The 20th percentile of the RR intervals (Han, 2017; Hovsepian, 2015).
         * **Prc80NN**: The 80th percentile of the RR intervals (Han, 2017; Hovsepian, 2015).
-        * **pNN50**: The proportion of RR intervals greater than 50ms, out of the total number of
-          RR intervals.
-        * **pNN20**: The proportion of RR intervals greater than 20ms, out of the total number of
-          RR intervals.
+        * **pNN50**: The percentage of absolute differences in successive RR intervals greater than
+          50 ms (Bigger et al., 1988; Mietus et al., 2002).
+        * **pNN20**: The percentage of absolute differences in successive RR intervals greater than
+          20 ms (Mietus et al., 2002).
         * **MinNN**: The minimum of the RR intervals (Parent, 2019; Subramaniam, 2022).
         * **MaxNN**: The maximum of the RR intervals (Parent, 2019; Subramaniam, 2022).
         * **TINN**: A geometrical parameter of the HRV, or more specifically, the baseline width of
@@ -89,6 +91,11 @@ def hrv_time(peaks, sampling_rate=1000, show=False, **kwargs):
     --------
     ecg_peaks, ppg_peaks, hrv_frequency, hrv_summary, hrv_nonlinear
 
+    Notes
+    -----
+
+    Where applicable, the unit used for these metrics is the millisecond.
+
     Examples
     --------
     .. ipython:: python
@@ -109,6 +116,9 @@ def hrv_time(peaks, sampling_rate=1000, show=False, **kwargs):
 
     References
     ----------
+    * Bigger Jr, J. T., Kleiger, R. E., Fleiss, J. L., Rolnitzky, L. M., Steinman, R. C., & Miller,
+      J. P. (1988). Components of heart rate variability measured during healing of acute myocardial
+      infarction. The American journal of cardiology, 61(4), 208-215.
     * Pham, T., Lau, Z. J., Chen, S. H. A., & Makowski, D. (2021). Heart Rate Variability in
       Psychology: A Review of HRV Indices and an Analysis Tutorial. Sensors, 21(12), 3998.
       https://doi.org/10.3390/s21123998
@@ -121,6 +131,8 @@ def hrv_time(peaks, sampling_rate=1000, show=False, **kwargs):
       towards a gold standard for continuous stress assessment in the mobile environment. In
       Proceedings of the 2015 ACM international joint conference on pervasive and ubiquitous
       computing (pp. 493-504).
+    * Mietus, J. E., Peng, C. K., Henry, I., Goldsmith, R. L., & Goldberger, A. L. (2002). The pNNx
+      files: re-examining a widely used heart rate variability measure. Heart, 88(4), 378-380.
     * Parent, M., Tiwari, A., Albuquerque, I., Gagnon, J. F., Lafond, D., Tremblay, S., & Falk, T.
       H. (2019). A multimodal approach to improve the robustness of physiological stress prediction
       during physical activity. In 2019 IEEE International Conference on Systems, Man and
@@ -132,6 +144,10 @@ def hrv_time(peaks, sampling_rate=1000, show=False, **kwargs):
     * Subramaniam, S. D., & Dass, B. (2022). An Efficient Convolutional Neural Network for Acute
       Pain Recognition Using HRV Features. In Proceedings of the International e-Conference on
       Intelligent Systems and Signal Processing (pp. 119-132). Springer, Singapore.
+    * Sollers, J. J., Buchanan, T. W., Mowrer, S. M., Hill, L. K., & Thayer, J. F. (2007).
+      Comparison of the ratio of the standard deviation of the RR interval and the root mean
+      squared successive differences (SD/rMSSD) to the low frequency-to-high frequency (LF/HF)
+      ratio in a patient population and normal healthy controls. Biomed Sci Instrum, 43, 158-163.
 
     """
     # Sanitize input
@@ -166,6 +182,7 @@ def hrv_time(peaks, sampling_rate=1000, show=False, **kwargs):
     out["MadNN"] = mad(rri)
     out["MCVNN"] = out["MadNN"] / out["MedianNN"]  # Normalized
     out["IQRNN"] = scipy.stats.iqr(rri)
+    out["SDRMSSD"] = out["SDNN"] / out["RMSSD"]  # Sollers (2007)
     out["Prc20NN"] = np.nanpercentile(rri, q=20)
     out["Prc80NN"] = np.nanpercentile(rri, q=80)
 
@@ -200,7 +217,6 @@ def hrv_time(peaks, sampling_rate=1000, show=False, **kwargs):
 
 
 def _hrv_time_show(rri, **kwargs):
-
     fig = summary_plot(rri, **kwargs)
     plt.xlabel("R-R intervals (ms)")
     fig.suptitle("Distribution of R-R intervals")
@@ -209,7 +225,6 @@ def _hrv_time_show(rri, **kwargs):
 
 
 def _sdann(rri, rri_time=None, window=1):
-
     window_size = window * 60 * 1000  # Convert window in min to ms
     if rri_time is None:
         # Compute the timestamps of the R-R intervals in seconds
@@ -230,7 +245,6 @@ def _sdann(rri, rri_time=None, window=1):
 
 
 def _sdnni(rri, rri_time=None, window=1):
-
     window_size = window * 60 * 1000  # Convert window in min to ms
     if rri_time is None:
         # Compute the timestamps of the R-R intervals in seconds
@@ -267,10 +281,14 @@ def _hrv_TINN(rri, bar_x, bar_y, binsize):
         while m < np.max(rri):
             n_start = np.where(bar_x == n)[0][0]
             n_end = np.where(bar_x == X)[0][0]
-            qn = np.polyval(np.polyfit([n, X], [0, Y], deg=1), bar_x[n_start : n_end + 1])
+            qn = np.polyval(
+                np.polyfit([n, X], [0, Y], deg=1), bar_x[n_start : n_end + 1]
+            )
             m_start = np.where(bar_x == X)[0][0]
             m_end = np.where(bar_x == m)[0][0]
-            qm = np.polyval(np.polyfit([X, m], [Y, 0], deg=1), bar_x[m_start : m_end + 1])
+            qm = np.polyval(
+                np.polyfit([X, m], [Y, 0], deg=1), bar_x[m_start : m_end + 1]
+            )
             q = np.zeros(len(bar_x))
             q[n_start : n_end + 1] = qn
             q[m_start : m_end + 1] = qm
