@@ -1,58 +1,122 @@
 # -*- coding: utf-8 -*-
-from warnings import warn
 
 import numpy as np
 import pandas as pd
 
-from ..misc import NeuroKitWarning
-from ..signal import signal_interpolate
+from .intervals_to_peaks import intervals_to_peaks
+from .intervals_utils import _intervals_sanitize
 
 
-def _hrv_get_rri(
-    peaks=None, sampling_rate=1000, interpolate=False, interpolation_rate=100, **kwargs
-):
-
+def _hrv_get_rri(peaks=None, sampling_rate=1000):
+    if peaks is None:
+        return None, None, None
+    # Compute R-R intervals (also referred to as NN) in milliseconds
     rri = np.diff(peaks) / sampling_rate * 1000
-
-    if interpolate is False:
-        interpolation_rate = None
-
-    else:
-        # Rate should be at least 1 Hz (due to Nyquist & frequencies we are interested in)
-        # We considered an interpolation rate 4 Hz by default to match Kubios
-        # but in case of some applications with high heart rates we decided to make it 100 Hz
-        # See https://github.com/neuropsychology/NeuroKit/pull/680 for more information
-        # and if you have any thoughts to contribute, please let us know!
-        if interpolation_rate < 1:
-            warn(
-                "The interpolation rate of the R-R intervals is too low for "
-                " computing the frequency-domain features."
-                " Consider increasing the interpolation rate to at least 1 Hz.",
-                category=NeuroKitWarning,
-            )
-
-        # Compute x-values of interpolated heart period signal at requested sampling rate.
-        x_new = np.arange(
-            start=peaks[1] / sampling_rate,
-            stop=peaks[-1] / sampling_rate + 1 / interpolation_rate,
-            step=1 / interpolation_rate,
-        )
-        rri_time = (
-            peaks[1:] / sampling_rate
-        )  # Skip first peak since it has no corresponding element in heart_period
-
-        rri = signal_interpolate(rri_time, rri, x_new=x_new, **kwargs)
-    return rri, interpolation_rate
+    rri, rri_time, rri_missing = _intervals_sanitize(rri)
+    return rri, rri_time, rri_missing
 
 
-def _hrv_sanitize_input(peaks=None):
+def _hrv_format_input(peaks=None, sampling_rate=1000, output_format="intervals"):
 
     if isinstance(peaks, tuple):
-        peaks = _hrv_sanitize_tuple(peaks)
+        rri, rri_time, rri_missing, sampling_rate = _hrv_sanitize_tuple(peaks, sampling_rate=sampling_rate)
     elif isinstance(peaks, (dict, pd.DataFrame)):
-        peaks = _hrv_sanitize_dict_or_df(peaks)
+        rri, rri_time, rri_missing, sampling_rate = _hrv_sanitize_dict_or_df(peaks, sampling_rate=sampling_rate)
     else:
         peaks = _hrv_sanitize_peaks(peaks)
+        rri, rri_time, rri_missing = _hrv_get_rri(peaks, sampling_rate=sampling_rate)
+    if output_format == "intervals":
+        return rri, rri_time, rri_missing
+    elif output_format == "peaks":
+        return (
+            intervals_to_peaks(rri, intervals_time=rri_time, sampling_rate=sampling_rate),
+            sampling_rate,
+        )
+
+
+# =============================================================================
+# Internals
+# =============================================================================
+def _hrv_sanitize_tuple(peaks, sampling_rate=1000):
+
+    # Get sampling rate
+    info = [i for i in peaks if isinstance(i, dict)]
+    sampling_rate = info[0]["sampling_rate"]
+
+    # Detect actual sampling rate
+    if len(info) < 1:
+        peaks, sampling_rate = peaks[0], peaks[1]
+
+    # Get peaks
+    if isinstance(peaks[0], (dict, pd.DataFrame)):
+        try:
+            peaks = _hrv_sanitize_dict_or_df(peaks[0])
+        except NameError:
+            if isinstance(peaks[1], (dict, pd.DataFrame)):
+                try:
+                    peaks = _hrv_sanitize_dict_or_df(peaks[1])
+                except NameError:
+                    peaks = _hrv_sanitize_peaks(peaks[1])
+            else:
+                peaks = _hrv_sanitize_peaks(peaks[0])
+
+    rri, rri_time, rri_missing = _hrv_get_rri(peaks=peaks, sampling_rate=sampling_rate)
+
+    return rri, rri_time, rri_missing, sampling_rate
+
+
+def _hrv_sanitize_dict_or_df(peaks, sampling_rate=None):
+
+    # Get columns
+    if isinstance(peaks, dict):
+        cols = np.array(list(peaks.keys()))
+        if "sampling_rate" in cols:
+            sampling_rate = peaks["sampling_rate"]
+    elif isinstance(peaks, pd.DataFrame):
+        cols = peaks.columns.values
+
+    # check whether R-R intervals were passed rather than peak indices
+    if "RRI" in cols:
+        rri = peaks["RRI"]
+        if "RRI_Time" in cols:
+            rri_time = peaks["RRI_Time"]
+        else:
+            rri_time = None
+        rri, rri_time, rri_missing = _intervals_sanitize(rri, intervals_time=rri_time)
+        return rri, rri_time, rri_missing, sampling_rate
+
+    cols = cols[["Peak" in s for s in cols]]
+
+    if len(cols) > 1:
+        cols = cols[[("ECG" in s) or ("PPG" in s) for s in cols]]
+
+    if len(cols) == 0:
+        raise NameError(
+            "NeuroKit error: hrv(): Wrong input, ",
+            "we couldn't extract R-peak indices. ",
+            "You need to provide a list of R-peak indices.",
+        )
+
+    peaks = _hrv_sanitize_peaks(peaks[cols[0]])
+
+    if sampling_rate is not None:
+        rri, rri_time, rri_missing = _hrv_get_rri(peaks=peaks, sampling_rate=sampling_rate)
+    else:
+        rri, rri_time, rri_missing = _hrv_get_rri(peaks=peaks)
+    return rri, rri_time, rri_missing, sampling_rate
+
+
+def _hrv_sanitize_peaks(peaks):
+
+    if isinstance(peaks, pd.Series):
+        peaks = peaks.values
+
+    if len(np.unique(peaks)) == 2:
+        if np.all(np.unique(peaks) == np.array([0, 1])):
+            peaks = np.where(peaks == 1)[0]
+
+    if isinstance(peaks, list):
+        peaks = np.array(peaks)
 
     if peaks is not None:
         if isinstance(peaks, tuple):
@@ -73,76 +137,3 @@ def _hrv_sanitize_input(peaks=None):
                 )
 
     return peaks
-
-
-# =============================================================================
-# Internals
-# =============================================================================
-def _hrv_sanitize_tuple(peaks):
-
-    # Get sampling rate
-    info = [i for i in peaks if isinstance(i, dict)]
-    sampling_rate = info[0]["sampling_rate"]
-
-    # Get peaks
-    if isinstance(peaks[0], (dict, pd.DataFrame)):
-        try:
-            peaks = _hrv_sanitize_dict_or_df(peaks[0])
-        except NameError:
-            if isinstance(peaks[1], (dict, pd.DataFrame)):
-                try:
-                    peaks = _hrv_sanitize_dict_or_df(peaks[1])
-                except NameError:
-                    peaks = _hrv_sanitize_peaks(peaks[1])
-            else:
-                peaks = _hrv_sanitize_peaks(peaks[0])
-
-    return peaks, sampling_rate
-
-
-def _hrv_sanitize_dict_or_df(peaks):
-
-    # Get columns
-    if isinstance(peaks, dict):
-        cols = np.array(list(peaks.keys()))
-        if "sampling_rate" in cols:
-            sampling_rate = peaks["sampling_rate"]
-        else:
-            sampling_rate = None
-    elif isinstance(peaks, pd.DataFrame):
-        cols = peaks.columns.values
-        sampling_rate = None
-
-    cols = cols[["Peak" in s for s in cols]]
-
-    if len(cols) > 1:
-        cols = cols[[("ECG" in s) or ("PPG" in s) for s in cols]]
-
-    if len(cols) == 0:
-        raise NameError(
-            "NeuroKit error: hrv(): Wrong input, ",
-            "we couldn't extract R-peak indices. ",
-            "You need to provide a list of R-peak indices.",
-        )
-
-    peaks = _hrv_sanitize_peaks(peaks[cols[0]])
-
-    if sampling_rate is not None:
-        return peaks, sampling_rate
-    else:
-        return peaks
-
-
-def _hrv_sanitize_peaks(peaks):
-
-    if isinstance(peaks, pd.Series):
-        peaks = peaks.values
-
-    if len(np.unique(peaks)) == 2:
-        if np.all(np.unique(peaks) == np.array([0, 1])):
-            peaks = np.where(peaks == 1)[0]
-
-    if isinstance(peaks, list):
-        peaks = np.array(peaks)
-
-    return peaks
