@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 import numpy as np
 
+from ..misc import check_random_state
 from ..stats import cluster
 from ..stats.cluster_quality import _cluster_quality_gev
 from .microstates_classify import microstates_classify
@@ -186,12 +187,11 @@ def microstates_segment(
     # Run clustering algorithm
     if method in ["kmods", "kmod", "kmeans modified", "modified kmeans"]:
 
-        # If no random state specified, generate a random state
-        if not isinstance(random_state, np.random.RandomState):
-            random_state = np.random.RandomState(random_state)
+        # Seed the random generator for reproducible results
+        rng = check_random_state(random_state)
 
         # Generate one random integer for each run
-        random_state = random_state.choice(range(n_runs * 1000), n_runs, replace=False)
+        random_state = rng.choice(n_runs * 1000, n_runs, replace=False)
 
         # Initialize values
         gev = 0
@@ -244,11 +244,7 @@ def microstates_segment(
     else:
         # Run clustering algorithm on subset
         _, microstates, info = cluster(
-            data[:, indices].T,
-            method=method,
-            n_clusters=n_microstates,
-            random_state=random_state,
-            **kwargs
+            data[:, indices].T, method=method, n_clusters=n_microstates, random_state=random_state, **kwargs
         )
 
         # Run segmentation on the whole dataset
