@@ -1,6 +1,11 @@
-"""Submodule for NeuroKit."""
+"""Submodule for NeuroKit.
+
+isort:skip_file (since isort-ing the imports generates circular imports)
+
+"""
 
 from ._warnings import NeuroKitWarning
+from .check_random_state import check_random_state, check_random_state_children, spawn_random_state
 from .check_type import check_type
 from .copyfunction import copyfunction
 from .expspace import expspace
@@ -15,6 +20,9 @@ from .parallel_run import parallel_run
 from .progress_bar import progress_bar
 from .replace import replace
 from .type_converters import as_vector
+from .report import create_report
+from .fig2img import fig2img
+
 
 __all__ = [
     "listify",
@@ -32,4 +40,9 @@ __all__ = [
     "progress_bar",
     "find_plateau",
     "copyfunction",
+    "check_random_state",
+    "check_random_state_children",
+    "spawn_random_state",
+    "create_report",
+    "fig2img",
 ]
