@@ -2,9 +2,9 @@
 
 import matplotlib.pyplot as plt
 import numpy as np
-import scipy.interpolate
 
-from ..signal import signal_distort
+from ..misc import check_random_state, check_random_state_children
+from ..signal import signal_distort, signal_interpolate
 
 
 def ppg_simulate(
@@ -19,6 +19,7 @@ def ppg_simulate(
     burst_number=0,
     burst_amplitude=1,
     random_state=None,
+    random_state_distort="spawn",
     show=False,
 ):
     """**Simulate a photoplethysmogram (PPG) signal**
@@ -62,8 +63,14 @@ def ppg_simulate(
         Determines how many high frequency burst artifacts occur. The default is 0.
     show : bool
         If ``True``, returns a plot of the landmarks and interpolated PPG. Useful for debugging.
-    random_state : int
-        Seed for the random number generator. Keep it fixed for reproducible results.
+    random_state : None, int, numpy.random.RandomState or numpy.random.Generator
+        Seed for the random number generator. See for ``misc.check_random_state`` for further information.
+    random_state_distort : {'legacy', 'spawn'}, None, int, numpy.random.RandomState or numpy.random.Generator
+        Random state to be used to distort the signal. If ``"legacy"``, use the same random state used to
+        generate the signal (discouraged as it creates dependent random streams). If ``"spawn"``, spawn
+        independent children random number generators from the random_state argument. If any of the other types,
+        generate independent children random number generators from the random_state_distort provided (this
+        allows generating multiple version of the same signal distorted by different random noise realizations).
 
     Returns
     -------
@@ -83,7 +90,9 @@ def ppg_simulate(
       ppg = nk.ppg_simulate(duration=40, sampling_rate=500, heart_rate=75, random_state=42)
 
     """
-    np.random.seed(random_state)
+    # Seed the random generator for reproducible results
+    rng = check_random_state(random_state)
+    random_state_distort = check_random_state_children(random_state, random_state_distort, n_children=4)
 
     # At the requested sampling rate, how long is a period at the requested
     # heart-rate and how often does that period fit into the requested
@@ -104,24 +113,24 @@ def ppg_simulate(
     )
     # Randomly modulate duration of waves by subracting a random value between
     # 0 and ibi_randomness% of the wave duration (see function definition).
-    x_onset = _random_x_offset(x_onset, ibi_randomness)
+    x_onset = _random_x_offset(x_onset, ibi_randomness, rng)
     # Corresponding signal amplitudes.
-    y_onset = np.random.normal(0, 0.1, n_period)
+    y_onset = rng.normal(0, 0.1, n_period)
 
     # Seconds at which the systolic peaks occur within the waves.
-    x_sys = x_onset + np.random.normal(0.175, 0.01, n_period) * periods
+    x_sys = x_onset + rng.normal(0.175, 0.01, n_period) * periods
     # Corresponding signal amplitudes.
-    y_sys = y_onset + np.random.normal(1.5, 0.15, n_period)
+    y_sys = y_onset + rng.normal(1.5, 0.15, n_period)
 
     # Seconds at which the dicrotic notches occur within the waves.
-    x_notch = x_onset + np.random.normal(0.4, 0.001, n_period) * periods
+    x_notch = x_onset + rng.normal(0.4, 0.001, n_period) * periods
     # Corresponding signal amplitudes (percentage of systolic peak height).
-    y_notch = y_sys * np.random.normal(0.49, 0.01, n_period)
+    y_notch = y_sys * rng.normal(0.49, 0.01, n_period)
 
     # Seconds at which the diastolic peaks occur within the waves.
-    x_dia = x_onset + np.random.normal(0.45, 0.001, n_period) * periods
+    x_dia = x_onset + rng.normal(0.45, 0.001, n_period) * periods
     # Corresponding signal amplitudes (percentage of systolic peak height).
-    y_dia = y_sys * np.random.normal(0.51, 0.01, n_period)
+    y_dia = y_sys * rng.normal(0.51, 0.01, n_period)
 
     x_all = np.concatenate((x_onset, x_sys, x_notch, x_dia))
     x_all.sort(kind="mergesort")
@@ -139,9 +148,8 @@ def ppg_simulate(
 
     # Interpolate a continuous signal between the landmarks (i.e., Cartesian
     # coordinates).
-    f = scipy.interpolate.Akima1DInterpolator(x_all, y_all)
     samples = np.arange(int(np.ceil(duration * sampling_rate)))
-    ppg = f(samples)
+    ppg = signal_interpolate(x_values=x_all, y_values=y_all, x_new=samples, method="akima")
     # Remove NAN (values outside interpolation range, i.e., after last sample).
     ppg[np.isnan(ppg)] = np.nanmean(ppg)
 
@@ -158,7 +166,7 @@ def ppg_simulate(
             sampling_rate=sampling_rate,
             noise_amplitude=drift,
             noise_frequency=drift_freq,
-            random_state=random_state,
+            random_state=random_state_distort[0],
             silent=True,
         )
     # Add motion artifacts.
@@ -169,7 +177,7 @@ def ppg_simulate(
             sampling_rate=sampling_rate,
             noise_amplitude=motion_amplitude,
             noise_frequency=motion_freq,
-            random_state=random_state,
+            random_state=random_state_distort[1],
             silent=True,
         )
     # Add high frequency bursts.
@@ -180,7 +188,7 @@ def ppg_simulate(
             artifacts_amplitude=burst_amplitude,
             artifacts_frequency=100,
             artifacts_number=burst_number,
-            random_state=random_state,
+            random_state=random_state_distort[2],
             silent=True,
         )
     # Add powerline noise.
@@ -190,7 +198,7 @@ def ppg_simulate(
             sampling_rate=sampling_rate,
             powerline_amplitude=powerline_amplitude,
             powerline_frequency=50,
-            random_state=random_state,
+            random_state=random_state_distort[3],
             silent=True,
         )
 
@@ -240,7 +248,7 @@ def _frequency_modulation(periods, seconds, modulation_frequency, modulation_str
     return periods_modulated, seconds_modulated
 
 
-def _random_x_offset(x, offset_weight):
+def _random_x_offset(x, offset_weight, rng):
     """From each wave onset xi subtract offset_weight * (xi - xi-1) where xi-1 is
     the wave onset preceding xi. offset_weight must be between 0 and 1.
     """
@@ -261,7 +269,7 @@ def _random_x_offset(x, offset_weight):
         return x
 
     max_offsets = offset_weight * x_diff
-    offsets = [np.random.uniform(0, i) for i in max_offsets]
+    offsets = [rng.uniform(0, i) for i in max_offsets]
 
     x_offset = x.copy()
     x_offset[1:] -= offsets
