@@ -6,9 +6,7 @@ from ..signal import signal_interpolate
 from .rsp_fixpeaks import _rsp_fixpeaks_retrieve
 
 
-def rsp_amplitude(
-    rsp_cleaned, peaks, troughs=None, method="standard", interpolation_method="monotone_cubic"
-):
+def rsp_amplitude(rsp_cleaned, peaks, troughs=None, method="standard", interpolation_method="monotone_cubic"):
     """**Compute respiratory amplitude**
 
     Compute respiratory amplitude given the raw respiration signal and its extrema. The
@@ -75,10 +73,13 @@ def rsp_amplitude(
       neurophysiology, 122(2), 849-861.
 
     """
+    # Make sure `rsp_cleaned` is a np.array
+    rsp_cleaned = np.array(rsp_cleaned)
+
     # Format input.
     peaks, troughs = _rsp_fixpeaks_retrieve(peaks, troughs)
 
-    # To consistenty calculate amplitude, peaks and troughs must have the same
+    # To consistently calculate amplitude, peaks and troughs must have the same
     # number of elements, and the first trough must precede the first peak.
     if (peaks.size != troughs.size) or (peaks[0] <= troughs[0]):
         raise TypeError(
@@ -104,8 +105,6 @@ def rsp_amplitude(
     if len(peaks) == 1:
         amplitude = np.full(rsp_cleaned.shape, amplitude[0])
     else:
-        amplitude = signal_interpolate(
-            peaks, amplitude, x_new=np.arange(len(rsp_cleaned)), method=interpolation_method
-        )
+        amplitude = signal_interpolate(peaks, amplitude, x_new=np.arange(len(rsp_cleaned)), method=interpolation_method)
 
     return amplitude
