@@ -2,12 +2,14 @@
 import pandas as pd
 
 from ..misc import as_vector
+from ..misc.report import create_report
 from ..signal import signal_rate
 from .rsp_amplitude import rsp_amplitude
 from .rsp_clean import rsp_clean
 from .rsp_methods import rsp_methods
 from .rsp_peaks import rsp_peaks
 from .rsp_phase import rsp_phase
+from .rsp_plot import rsp_plot
 from .rsp_rvt import rsp_rvt
 from .rsp_symmetry import rsp_symmetry
 
@@ -17,6 +19,7 @@ def rsp_process(
     sampling_rate=1000,
     method="khodadad2018",
     method_rvt="harrison2021",
+    report=None,
     **kwargs
 ):
     """**Process a respiration (RSP) signal**
@@ -40,6 +43,11 @@ def rsp_process(
     method_rvt : str
         The rvt method to apply. Can be one of ``"harrison2021"`` (default), ``"birn2006"``
         or ``"power2020"``.
+    report : str
+        The filename of a report containing description and figures of processing
+        (e.g. ``"myreport.html"``). Needs to be supplied if a report file
+        should be generated. Defaults to ``None``. Can also be ``"text"`` to
+        just print the text in the console without saving anything.
     **kwargs
         Other arguments to be passed to specific methods. For more information,
         see :func:`.rsp_methods`.
@@ -49,18 +57,19 @@ def rsp_process(
     signals : DataFrame
         A DataFrame of same length as :func:`.rsp_signal` containing the following columns:
 
-        * ``"RSP_Raw"``: the raw signal.
-        * ``"RSP_Clean"``: the cleaned signal.
-        * ``"RSP_Peaks"``: the respiratory peaks (exhalation onsets) marked as "1" in a list of
-          zeros.
-        * ``"RSP_Troughs"``: the respiratory troughs (inhalation onsets) marked as "1" in a list of
-          zeros.
-        * ``"RSP_Rate"``: breathing rate interpolated between inhalation peaks.
-        * ``"RSP_Amplitude"``: breathing amplitude interpolated between inhalation peaks.
-        * ``"RSP_Phase"``: breathing phase, marked by "1" for inspiration and "0" for expiration.
-        * ``"RSP_PhaseCompletion"``: breathing phase completion, expressed in percentage (from 0 to
-          1), representing the stage of the current respiratory phase.
-         * ``"RSP_RVT"``: respiratory volume per time (RVT).
+        .. codebookadd::
+            RSP_Raw|The raw signal.
+            RSP_Clean|The raw signal.
+            RSP_Peaks|The respiratory peaks (exhalation onsets) marked as "1" in a list of zeros.
+            RSP_Troughs|The respiratory troughs (inhalation onsets) marked as "1" in a list \
+                of zeros.
+            RSP_Rate|The breathing rate interpolated between inhalation peaks.
+            RSP_Amplitude|The breathing amplitude interpolated between inhalation peaks.
+            RSP_Phase|The breathing phase, marked by "1" for inspiration and "0" for expiration.
+            RSP_Phase_Completion|The breathing phase completion, expressed in percentage \
+                (from 0 to 1), representing the stage of the current respiratory phase.
+            RSP_RVT|Respiratory volume per time (RVT).
+
     info : dict
         A dictionary containing the samples at which inhalation peaks and exhalation troughs occur,
         accessible with the keys ``"RSP_Peaks"``, and ``"RSP_Troughs"`` respectively, as well as the
@@ -77,10 +86,10 @@ def rsp_process(
       import neurokit2 as nk
 
       rsp = nk.rsp_simulate(duration=90, respiratory_rate=15)
-      signals, info = nk.rsp_process(rsp, sampling_rate=1000)
+      signals, info = nk.rsp_process(rsp, sampling_rate=1000, report="text")
 
       @savefig p_rsp_process_1.png scale=100%
-      fig = nk.rsp_plot(signals, sampling_rate=1000)
+      fig = nk.rsp_plot(signals, info)
       @suppress
       plt.close()
 
@@ -92,19 +101,12 @@ def rsp_process(
     )
 
     # Clean signal
-    if (
-        methods["method_cleaning"] is None
-        or methods["method_cleaning"].lower() == "none"
-    ):
-        rsp_cleaned = rsp_signal
-    else:
-        # Clean signal
-        rsp_cleaned = rsp_clean(
-            rsp_signal,
-            sampling_rate=sampling_rate,
-            method=methods["method_cleaning"],
-            **methods["kwargs_cleaning"],
-        )
+    rsp_cleaned = rsp_clean(
+        rsp_signal,
+        sampling_rate=sampling_rate,
+        method=methods["method_cleaning"],
+        **methods["kwargs_cleaning"],
+    )
 
     # Extract, fix and format peaks
     peak_signal, info = rsp_peaks(
@@ -142,4 +144,12 @@ def rsp_process(
     )
     signals = pd.concat([signals, phase, symmetry, peak_signal], axis=1)
 
+    if report is not None:
+        # Generate report containing description and figures of processing
+        if ".html" in str(report):
+            fig = rsp_plot(signals, info)
+        else:
+            fig = None
+        create_report(file=report, signals=signals, info=methods, fig=fig)
+
     return signals, info
