@@ -53,6 +53,7 @@ def signal_binarize(signal, method="threshold", threshold="auto"):
     elif isinstance(signal, pd.Series):
         signal = signal.copy()  # Avoid annoying pandas warning
         binary = _signal_binarize(signal.values, method=method, threshold=threshold)
+        signal = signal.astype(binary.dtype)
         signal[:] = binary
     else:
         signal = _signal_binarize(signal, method=method, threshold=threshold)
@@ -100,7 +101,9 @@ def _signal_binarize_mixture(signal, threshold="auto"):
     clf = clf.fit(signal.reshape(-1, 1))
 
     # Get predicted probabilities
-    probability = clf.predict_proba(signal.reshape(-1, 1))[:, np.argmax(clf.means_[:, 0])]
+    probability = clf.predict_proba(signal.reshape(-1, 1))[
+        :, np.argmax(clf.means_[:, 0])
+    ]
 
     binary = np.zeros(len(signal))
     binary[probability >= threshold] = 1
