@@ -69,7 +69,8 @@ def signal_psd(
         The timestamps corresponding to each sample in the signal, in seconds
         (for ``"lombscargle"`` method). Defaults to None.
     **kwargs : optional
-        Keyword arguments to be passed to :func:`.scipy.signal.welch`.
+        Keyword arguments to be passed to :func:`.scipy.signal.welch` or :func:`.np.fft.rfft` (when
+        method is 'fft', such as `n`, which determines the number of windows).
 
     See Also
     --------
@@ -128,6 +129,10 @@ def signal_psd(
       plt.close()
 
     """
+    # Sanitize signal
+    if isinstance(signal, pd.Series):
+        signal = signal.values
+
     # Constant Detrend
     signal = signal - np.mean(signal)
 
@@ -137,22 +142,39 @@ def signal_psd(
     # Sanitize min_frequency
     N = len(signal)
     if isinstance(min_frequency, str):
-        min_frequency = (2 * sampling_rate) / (N / 2)  # for high frequency resolution
+        if sampling_rate is None:
+            # This is to compute min_frequency if both min_frequency and sampling_rate are not provided (#800)
+            min_frequency = (2 * np.median(np.diff(t))) / (
+                N / 2
+            )  # for high frequency resolution
+        else:
+            min_frequency = (2 * sampling_rate) / (
+                N / 2
+            )  # for high frequency resolution
 
     # MNE
     if method in ["multitaper", "multitapers", "mne"]:
         frequency, power = _signal_psd_multitaper(
-            signal, sampling_rate=sampling_rate, min_frequency=min_frequency, max_frequency=max_frequency,
+            signal,
+            sampling_rate=sampling_rate,
+            min_frequency=min_frequency,
+            max_frequency=max_frequency,
         )
 
     # FFT (Numpy)
     elif method in ["fft"]:
-        frequency, power = _signal_psd_fft(signal, sampling_rate=sampling_rate, **kwargs)
+        frequency, power = _signal_psd_fft(
+            signal, sampling_rate=sampling_rate, **kwargs
+        )
 
     # Lombscargle (AtroPy)
     elif method.lower() in ["lombscargle", "lomb"]:
         frequency, power = _signal_psd_lomb(
-            signal, sampling_rate=sampling_rate, min_frequency=min_frequency, max_frequency=max_frequency, t=t
+            signal,
+            sampling_rate=sampling_rate,
+            min_frequency=min_frequency,
+            max_frequency=max_frequency,
+            t=t,
         )
 
     # Method that are using a window
@@ -181,7 +203,11 @@ def signal_psd(
         # Welch (Scipy)
         if method.lower() in ["welch"]:
             frequency, power = _signal_psd_welch(
-                signal, sampling_rate=sampling_rate, nperseg=nperseg, window_type=window_type, **kwargs,
+                signal,
+                sampling_rate=sampling_rate,
+                nperseg=nperseg,
+                window_type=window_type,
+                **kwargs,
             )
 
         # BURG
@@ -204,11 +230,19 @@ def signal_psd(
     data = pd.DataFrame({"Frequency": frequency, "Power": power})
 
     # Filter
-    data = data.loc[np.logical_and(data["Frequency"] >= min_frequency, data["Frequency"] <= max_frequency)]
+    data = data.loc[
+        np.logical_and(
+            data["Frequency"] >= min_frequency, data["Frequency"] <= max_frequency
+        )
+    ]
     #    data["Power"] = 10 * np.log(data["Power"])
 
     if show is True:
-        ax = data.plot(x="Frequency", y="Power", title="Power Spectral Density (" + str(method) + " method)")
+        ax = data.plot(
+            x="Frequency",
+            y="Power",
+            title="Power Spectral Density (" + str(method) + " method)",
+        )
         ax.set(xlabel="Frequency (Hz)", ylabel="Spectrum")
 
     return data
@@ -231,7 +265,9 @@ def _signal_psd_fft(signal, sampling_rate=1000, n=None):
 # =============================================================================
 
 
-def _signal_psd_multitaper(signal, sampling_rate=1000, min_frequency=0, max_frequency=np.inf):
+def _signal_psd_multitaper(
+    signal, sampling_rate=1000, min_frequency=0, max_frequency=np.inf
+):
     try:
         import mne
     except ImportError as e:
@@ -259,7 +295,9 @@ def _signal_psd_multitaper(signal, sampling_rate=1000, min_frequency=0, max_freq
 # =============================================================================
 
 
-def _signal_psd_welch(signal, sampling_rate=1000, nperseg=None, window_type="hann", **kwargs):
+def _signal_psd_welch(
+    signal, sampling_rate=1000, nperseg=None, window_type="hann", **kwargs
+):
     if nperseg is not None:
         nfft = int(nperseg * 2)
     else:
@@ -285,7 +323,9 @@ def _signal_psd_welch(signal, sampling_rate=1000, nperseg=None, window_type="han
 # =============================================================================
 
 
-def _signal_psd_lomb(signal, sampling_rate=1000, min_frequency=0, max_frequency=np.inf, t=None):
+def _signal_psd_lomb(
+    signal, sampling_rate=1000, min_frequency=0, max_frequency=np.inf, t=None
+):
 
     try:
         import astropy.timeseries
@@ -294,15 +334,17 @@ def _signal_psd_lomb(signal, sampling_rate=1000, min_frequency=0, max_frequency=
             if max_frequency == np.inf:
                 max_frequency = sampling_rate / 2  # sanitize highest frequency
             t = np.arange(len(signal)) / sampling_rate
-            frequency, power = astropy.timeseries.LombScargle(t, signal, normalization="psd").autopower(
+            frequency, power = astropy.timeseries.LombScargle(
+                t, signal, normalization="psd"
+            ).autopower(
                 minimum_frequency=min_frequency, maximum_frequency=max_frequency
             )
         else:
             # determine maximum frequency with astropy defaults for unevenly spaced data
             # https://docs.astropy.org/en/stable/api/astropy.timeseries.LombScargle.html#astropy.timeseries.LombScargle.autopower
-            frequency, power = astropy.timeseries.LombScargle(t, signal, normalization="psd").autopower(
-                minimum_frequency=min_frequency
-            )
+            frequency, power = astropy.timeseries.LombScargle(
+                t, signal, normalization="psd"
+            ).autopower(minimum_frequency=min_frequency)
 
     except ImportError as e:
         raise ImportError(
@@ -320,12 +362,22 @@ def _signal_psd_lomb(signal, sampling_rate=1000, min_frequency=0, max_frequency=
 
 
 def _signal_psd_burg(
-    signal, sampling_rate=1000, order=16, criteria="KIC", corrected=True, side="one-sided", nperseg=None,
+    signal,
+    sampling_rate=1000,
+    order=16,
+    criteria="KIC",
+    corrected=True,
+    side="one-sided",
+    nperseg=None,
 ):
 
     nfft = int(nperseg * 2)
-    ar, rho, _ = _signal_arma_burg(signal, order=order, criteria=criteria, corrected=corrected)
-    psd = _signal_psd_from_arma(ar=ar, rho=rho, sampling_rate=sampling_rate, nfft=nfft, side=side)
+    ar, rho, _ = _signal_arma_burg(
+        signal, order=order, criteria=criteria, corrected=corrected
+    )
+    psd = _signal_psd_from_arma(
+        ar=ar, rho=rho, sampling_rate=sampling_rate, nfft=nfft, side=side
+    )
 
     # signal is real, not complex
     if nfft % 2 == 0:
@@ -370,7 +422,9 @@ def _signal_arma_burg(signal, order=16, criteria="KIC", corrected=True):
     denominator = rho * 2.0 * N
 
     ar = np.zeros(0, dtype=complex)  # AR parametric signal model estimate
-    ref = np.zeros(0, dtype=complex)  # vector K of reflection coefficients (parcor coefficients)
+    ref = np.zeros(
+        0, dtype=complex
+    )  # vector K of reflection coefficients (parcor coefficients)
     ef = signal.astype(complex)  # forward prediction error
     eb = signal.astype(complex)  # backward prediction error
     temp = 1.0
@@ -390,7 +444,9 @@ def _signal_arma_burg(signal, order=16, criteria="KIC", corrected=True):
 
         if criteria is not None:
             # k=k+1 because order goes from 1 to P whereas k starts at 0.
-            residual_new = _criteria(criteria=criteria, N=N, k=k + 1, rho=new_rho, corrected=corrected)
+            residual_new = _criteria(
+                criteria=criteria, N=N, k=k + 1, rho=new_rho, corrected=corrected
+            )
             if k == 0:
                 residual_old = 2.0 * abs(residual_new)
 
@@ -402,7 +458,9 @@ def _signal_arma_burg(signal, order=16, criteria="KIC", corrected=True):
             residual_old = residual_new
         rho = new_rho
         if rho <= 0:
-            raise ValueError(f"Found a negative value (expected positive strictly) {rho}. Decrease the order.")
+            raise ValueError(
+                f"Found a negative value (expected positive strictly) {rho}. Decrease the order."
+            )
 
         ar = np.resize(ar, ar.size + 1)
         ar[k] = kp
@@ -419,7 +477,9 @@ def _signal_arma_burg(signal, order=16, criteria="KIC", corrected=True):
                 ar_previous = ar[j]  # previous value
                 ar[j] = ar_previous + kp * ar[k - j - 1].conjugate()  # Eq. (8.2)
                 if j != k - j - 1:
-                    ar[k - j - 1] = ar[k - j - 1] + kp * ar_previous.conjugate()  # Eq. (8.2)
+                    ar[k - j - 1] = (
+                        ar[k - j - 1] + kp * ar_previous.conjugate()
+                    )  # Eq. (8.2)
 
             # Update the forward and backward prediction errors
             for j in range(N - 1, k, -1):
@@ -477,7 +537,11 @@ def _criteria(criteria=None, N=None, k=None, rho=None, corrected=True):
 
     elif criteria == "KIC":
         if corrected is True:
-            residual = np.log(rho) + k / N / (N - k) + (3.0 - (k + 2.0) / N) * (k + 1.0) / (N - k - 2.0)
+            residual = (
+                np.log(rho)
+                + k / N / (N - k)
+                + (3.0 - (k + 2.0) / N) * (k + 1.0) / (N - k - 2.0)
+            )
         else:
             residual = np.log(rho) + 3.0 * (k + 1.0) / float(N)
 
@@ -492,7 +556,9 @@ def _criteria(criteria=None, N=None, k=None, rho=None, corrected=True):
     return residual
 
 
-def _signal_psd_from_arma(ar=None, ma=None, rho=1.0, sampling_rate=1000, nfft=None, side="one-sided"):
+def _signal_psd_from_arma(
+    ar=None, ma=None, rho=1.0, sampling_rate=1000, nfft=None, side="one-sided"
+):
 
     if ar is None and ma is None:
         raise ValueError("Either AR or MA model must be provided")
