@@ -1,9 +1,12 @@
 # -*- coding: utf-8 -*-
+import numpy as np
 import pandas as pd
 
 
 def signal_sanitize(signal):
-    """**Reset indexing for Pandas Series**
+    """**Signal input sanitization**
+
+    Reset indexing for Pandas Series.
 
     Parameters
     ----------
@@ -33,6 +36,6 @@ def signal_sanitize(signal):
 
     # Series check for non-default index
     if isinstance(signal, pd.Series) and not isinstance(signal.index, pd.RangeIndex):
-        return signal.reset_index(drop=True)
+        return signal.reset_index(drop=True).values
 
-    return signal
+    return np.array(signal)
