@@ -7,14 +7,14 @@ from .density import density
 
 
 def hdi(x, ci=0.95, show=False, **kwargs):
-    """Highest Density Interval (HDI)
+    """**Highest Density Interval (HDI)**
 
     Compute the Highest Density Interval (HDI) of a distribution. All points within this interval
     have a higher probability density than points outside the interval. The HDI can be used in the
-    context of uncertainty characterisation of posterior distributions (in the Bayesian farmework) as
-    Credible Interval (CI). Unlike equal-tailed intervals that typically exclude 2.5% from each tail
-    of the distribution and always include the median, the HDI is not equal-tailed and therefore always
-    includes the mode(s) of posterior distributions.
+    context of uncertainty characterisation of posterior distributions (in the Bayesian farmework)
+    as Credible Interval (CI). Unlike equal-tailed intervals that typically exclude 2.5% from each
+    tail of the distribution and always include the median, the HDI is not equal-tailed and
+    therefore always includes the mode(s) of posterior distributions.
 
     Parameters
     ----------
@@ -24,9 +24,9 @@ def hdi(x, ci=0.95, show=False, **kwargs):
         Value of probability of the (credible) interval - CI (between 0 and 1) to be estimated.
         Default to .95 (95%).
     show : bool
-        If True, the function will produce a figure.
+        If ``True``, the function will produce a figure.
     **kwargs : Line2D properties
-        Other arguments to be passed to ``density()``.
+        Other arguments to be passed to :func:`nk.density`.
 
     See Also
     --------
@@ -41,18 +41,25 @@ def hdi(x, ci=0.95, show=False, **kwargs):
 
     Examples
     ----------
-    >>> import numpy as np
-    >>> import neurokit2 as nk
-    >>>
-    >>> x = np.random.normal(loc=0, scale=1, size=100000)
-    >>> ci_min, ci_high = nk.hdi(x, ci=0.95, show=True)
+    .. ipython:: python
+
+      import numpy as np
+      import neurokit2 as nk
+
+      x = np.random.normal(loc=0, scale=1, size=100000)
+      @savefig p_hdi1.png scale=100%
+      ci_min, ci_high = nk.hdi(x, ci=0.95, show=True)
+      @suppress
+      plt.close()
 
     """
     x_sorted = np.sort(x)
     window_size = np.ceil(ci * len(x_sorted)).astype("int")
 
     if window_size < 2:
-        raise ValueError("NeuroKit error: hdi(): `ci` is too small or x does not contain enough data points.")
+        raise ValueError(
+            "NeuroKit error: hdi(): `ci` is too small or x does not contain enough data points."
+        )
 
     nCIs = len(x_sorted) - window_size
 
@@ -78,7 +85,11 @@ def _hdi_plot(vals, hdi_low, hdi_high, ci=0.95, **kwargs):
     fig, ax = plt.subplots()  # pylint: disable=unused-variable
     ax.plot(x, y, color="white")
     ax.fill_between(
-        x, y, where=where, color="#E91E63", label="CI {:.0%} [{:.2f}, {:.2f}]".format(ci, hdi_low, hdi_high)
+        x,
+        y,
+        where=where,
+        color="#E91E63",
+        label="CI {:.0%} [{:.2f}, {:.2f}]".format(ci, hdi_low, hdi_high),
     )
     ax.fill_between(x, y, where=~where, color="#2196F3")
     ax.legend(loc="upper right")
